# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibProducers as FnGeolibProducers
import LookFileBakeAPI as LookFileBakeAPI
import Nodes3DAPI.LookFileBaking as LookFileBaking
import NodegraphAPI as NodegraphAPI
import Utils as Utils
import typing
from LookFileBakeAPI.Constants import OutputFormat as OutputFormat
from LookFileBakeAPI.Exceptions import LookFileBakeException as LookFileBakeException
from Nodes3DAPI.Node3D import Node3D as Node3D
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

class LookFileBake(Node3D):
    def __init__(self) -> None: ...
    def AddPassInput(self, passName: str): ...
    def CheckRootLocations(self, rootLocations, origProducer, asmbCmptDict: Incomplete | None = ...): ...
    def DeletePassInput(self, index: int): ...
    def PostLookFileBake(self, assetId, asmbCmptDict, progressCallback: typing.Optional[typing.Callable] = ..., abortCallback: typing.Optional[typing.Callable] = ...): ...
    def PreLookFileBake(self, assetId, asmbCmptDict, progressCallback: typing.Optional[typing.Callable] = ..., abortCallback: typing.Optional[typing.Callable] = ...): ...
    def RenamePassInput(self, index: int, newName: str): ...
    def ReorderInput(self, index: int, newIndex: int): ...
    def WriteLookFileBakeScriptFiles(self, sessionPath: str, graphState: NodegraphAPI.GraphState, versionup: bool, publish: bool): ...
    def WriteLookFileToDirectory(self, outputFormatName, graphState: NodegraphAPI.GraphState, dirPath, includeGlobalAttributes: bool = ..., includeLodInfo: bool = ..., progressCallback: typing.Optional[typing.Callable] = ..., passName: Incomplete | None = ...): ...
    def WriteToAsset(self, graphState: NodegraphAPI.GraphState, assetId, args: Incomplete | None = ..., progressCallback: typing.Optional[typing.Callable] = ...): ...
    def WriteToCompoundFile(self, graphState: Tuple[NodegraphAPI.GraphState, float | None], dirPath: str, includeGlobalAttributes: bool = ..., includeLodInfo: bool = ..., progressCallback: typing.Optional[typing.Callable] = ..., passName: Incomplete | None = ...) -> list[str]: ...
    def WriteToDirectory(self, graphState: Tuple[NodegraphAPI.GraphState, float | None], dirPath: str, includeGlobalAttributes: bool = ..., includeLodInfo: bool = ..., progressCallback: typing.Optional[typing.Callable] = ..., passName: Incomplete | None = ...) -> list[str]: ...
    def WriteToLookFile(self, graphState: Tuple[NodegraphAPI.GraphState, float | None], filePath: str, includeGlobalAttributes: bool = ..., includeLodInfo: bool = ..., progressCallback: typing.Optional[typing.Callable] = ..., passName: Incomplete | None = ...): ...
    def _LookFileBake__getBakerOps(self, passInputPortNames, graphState: NodegraphAPI.GraphState): ...
    def _LookFileBake__getIncludeGlobalAttributes(self, frameTime): ...
    def _LookFileBake__getIncludeLodInfo(self, frameTime): ...
    def _LookFileBake__getMaterialTreeRootLocations(self, frameTime): ...
    def _LookFileBake__getOutputFormatName(self, frameTime): ...
    def _LookFileBake__getRootLocations(self, frameTime): ...
    @staticmethod
    def _LookFileBake__getSourceFile(): ...
    def _getOpChain(self, interface): ...
    def _getPassInputPortNames(self): ...
    def _getPassInputPorts(self): ...
    def _getReferenceInputPort(self): ...
    def _getReferenceInputPortName(self): ...
    def addParameterHints(self, attrName, inputDict): ...
    def getOrigProducer(self, graphState: NodegraphAPI.GraphState, portName: Incomplete | None = ..., addCELMatchOp: bool = ...): ...
    def getReferenceProducer(self, graphState: NodegraphAPI.GraphState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import Utils as Utils
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

class ArrayParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def _ArrayParameterPolicy__checkForUpdate(self, final: bool = ...): ...
    def _freeze(self): ...
    def _handleParamChanged(self, args): ...
    def _handleParamFinalized(self, args): ...
    def _handleTimeChanged(self, final): ...
    def _thaw(self): ...
    def getArrayChild(self, index: int) -> BaseParameterPolicy.BaseParameterPolicy | None: ...
    def getArraySize(self): ...
    def getNumChildren(self): ...
    def getType(self): ...
    def removeArrayChild(self, index: int): ...
    def removeArrayChildren(self, index: int, count: int): ...
    def reorderArrayChild(self, oldIndex: int, newIndex: int): ...
    def reorderArrayChildren(self, oldIndex: int, newIndex: int, count: int): ...
    def setArraySize(self, size): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.ParameterCurveEditSet as ParameterCurveEditSet
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyFCurve as PyFCurve
import QT4FormWidgets as QT4FormWidgets
import Utils as Utils
from UI4.FormMaster.BaseParameterPolicy import BaseParameterPolicy as BaseParameterPolicy
from typing import Set, Tuple

ALLOWED_TYPES: tuple

class ScalarParameterPolicy(BaseParameterPolicy):
    def __init__(self, param, parent) -> None: ...
    def _ScalarParameterPolicy__checkForUpdate(self, final): ...
    def _ScalarParameterPolicy__getFullValue(self, param): ...
    def _ScalarParameterPolicy__isConstant(self): ...
    def _freeze(self): ...
    def _getFullValue(self, param: NodegraphAPI.Parameter) -> Tuple[None, str, bool]: ...
    def _handleParamChanged(self, args): ...
    def _handleParamFinalized(self, args): ...
    def _handleTimeChanged(self, final): ...
    def _hintsChanged(self): ...
    def _thaw(self): ...
    def bakeCurve(self, keys): ...
    def canHaveCurve(self): ...
    def getCurve(self): ...
    def getCurveAutoKey(self): ...
    def getCurveKey(self): ...
    def getValue(self): ...
    def getValueAsString(self): ...
    def hasFloatingCurve(self): ...
    def isCurveEnabled(self): ...
    def isCurveViewed(self): ...
    def loadCurveFromFile(self, path, curvename: str = ...): ...
    def setCurve(self, curve): ...
    def setCurveAutoKey(self, autoKey): ...
    def setCurveEnabled(self, state): ...
    def setCurveKey(self, state, final: bool = ...): ...
    def setCurveViewed(self, state): ...
    def setValue(self, value, final: bool = ...): ...
    def setValueFromString(self, strValue, final: bool = ...): ...
    def writeCurveToFile(self, path): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.RenderManager as RenderManager
import UI4.FormMaster.BaseParameterPolicy
import UI4.Widgets.SceneGraphView.Bridge
import Nodes3DAPI.UpdateModes as UpdateModes
import Utils as Utils
from UI4.Widgets.DoubleSpinBox import DoubleSpinBox as DoubleSpinBox
from UI4.Widgets.SceneGraphView.ColumnDataType import RegisterDataType as RegisterDataType
from UI4.Widgets.SceneGraphView.ItemDelegates.ParameterItemDelegate import ParameterItemDelegate as ParameterItemDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class NumberItemDelegate(ParameterItemDelegate):
    DefaultColumnWidth: ClassVar[int] = ...
    Precision: ClassVar[int] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    @staticmethod
    def _NumberItemDelegate__formatFloat(value, precision): ...
    def _NumberItemDelegate__on_editor_valueChanged(self, value: float): ...
    def createEditor(self, parent: PyQt5.QtWidgets.QWidget, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> PyQt5.QtWidgets.QWidget | None: ...
    def doesParameterValueMatchModelValue(self, parameterPolicy: BaseParameterPolicy[UI4.FormMaster.BaseParameterPolicy.BaseParameterPolicy], index: PyQt5.QtCore.QModelIndex) -> bool: ...
    def editorClosed(self, editor: PyQt5.QtWidgets.QWidget, endEditHint: PyQt5.QtWidgets.QAbstractItemDelegate.EndEditHint): ...
    def getEditorClass(self) -> PyQt5.QtWidgets.QWidget | None: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def setEditorData(self, editor: PyQt5.QtWidgets.QWidget, index: PyQt5.QtCore.QModelIndex): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import RenderOutputLocation as RenderOutputLocation, Renderer as Renderer, RendererInfo as RendererInfo
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import KatanaResources as KatanaResources
import PyXmlIO as PyXmlIO
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
from _typeshed import Incomplete
from typing import Set, Tuple

class LineDrawable:
    def __init__(self, p1, p2, lineColor: tuple = ..., lineWidth: int = ..., **kwargs) -> None: ...
    def draw(self): ...

class MaskLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def advanceMask(self): ...
    def getActiveMask(self): ...
    def getAutoScale(self): ...
    def getMasks(self): ...
    def isEnabled(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setAutoScale(self, autoScaleEnabled): ...
    def setEnabled(self, isEnabled): ...
    def setMask(self, maskName): ...
    def toggleEnabled(self): ...

class MaskRectDrawable:
    def __init__(self, window: Incomplete | None = ..., fillColor: Incomplete | None = ..., outlineColor: Incomplete | None = ..., outlineStippleSize: int = ..., outlineWidth: int = ..., holdoutWindow: Incomplete | None = ..., label: str = ..., labelColor: tuple = ..., labelSize: float = ..., **kwargs) -> None: ...
    def _MaskRectDrawable__drawFill(self): ...
    def _MaskRectDrawable__drawLabel(self): ...
    def _MaskRectDrawable__drawOutline(self): ...
    def draw(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui as QtGui
from typing import ClassVar, Set, Tuple

class RolloverPixmap:
    IconMode: ClassVar[int] = ...
    PixmapMode: ClassVar[int] = ...
    def __init__(self, offMap, onMap) -> None: ...
    def enterEvent(self, e): ...
    def leaveEvent(self, e): ...
    def offMap(self): ...
    def onMap(self): ...
    def setOffMap(self, offMap): ...
    def setOnMap(self, onMap): ...
    def setRolloverEnabled(self, state): ...
    def showOffMap(self): ...
    def showOnMap(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.ExternalTools as ExternalTools
import UI4.App.Icon as Icon
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.App.Splash as Splash
import UI4.App.Splash
from typing import Set, Tuple

class AboutKatanaDialog(PyQt5.QtWidgets.QDialog, UI4.App.Splash.SplashScreenMixin):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    def _AboutKatanaDialog__on_aboutQtButton_clicked(self): ...
    def _AboutKatanaDialog__on_copyrightButton_clicked(self): ...
    def _AboutKatanaDialog__on_creditsButton_clicked(self): ...
    def mousePressEvent(self, event: PyQt5.QtGui.QMouseEvent): ...
    def sizeHint(self) -> PyQt5.QtCore.QSize: ...

class TextDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, text: str, parent: PyQt5.QtWidgets.QWidget) -> None: ...
    def _TextDialog__on_richTextLabel_linkActivated(self, link: str): ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...

def AboutKatana(window): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import PyQt5.QtCore as QtCore
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import PyUtilModule.RenderManager as RenderManager
import UI4 as UI4
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget
from QT4FormWidgets.WidgetFactory import WidgetFactory
from typing import Set, Tuple

class CameraPickerFormWidget(BaseValueFormWidget):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, policy: QT4FormWidgets.ValuePolicy.AbstractValuePolicy, factory: WidgetFactory) -> None: ...
    def _buildControlWidget(self, layout: PyQt5.QtWidgets.QLayout) -> PyQt5.QtWidgets.QWidget: ...
    def _lockChanged(self, state: bool): ...
    def _updateControlWidget(self): ...
    def on_cameraPickerButton_popupClosed(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from _typeshed import Incomplete
from typing import Set, Tuple

class ViewerWorkingSetButton(ToolbarButton):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, viewerManager: Incomplete | None = ...) -> None: ...
    def _ViewerWorkingSetButton__on_toggled(self): ...
    def _ViewerWorkingSetButton__on_viewer_visibilityFollowsWorkingSetChanged(self, eventType, eventID, visibilityFollowsWorkingSet): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI.Constants.ApplyWhenOptions as ApplyWhenOptions
import NodegraphAPI.Constants.ApplyWhereOptions as ApplyWhereOptions
import ConditionalStateGrammar as ConditionalStateGrammar
import NodegraphAPI.Constants.ExecutionModeOptions as ExecutionModeOptions
import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import PyFnGeolibServices as FnGeolibServices
import NodegraphAPI as NodegraphAPI
import PyFnAttribute
import PyXmlIO as PyXmlIO
import Utils as Utils
from ConditionalStateGrammar.Parser import ParseCSG as ParseCSG
from Nodes3DAPI.Node3D import Node3D as Node3D
from typing import ClassVar, Set, Tuple

_ExtraHints: dict

class GenericOp(Node3D):
    def __init__(self) -> None: ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def buildArgsParametersFromAttr(self, attr): ...
    def updateArgsParametersFromAttr(self, groupAttr: PyFnAttribute.GroupAttribute): ...

class _ParamUpdater:
    intHint: ClassVar[str] = ...
    metaPrefix: ClassVar[str] = ...
    typeTable: ClassVar[dict] = ...
    @classmethod
    def _ParamUpdater__deleteParam(cls, parentParam: NodegraphAPI.Parameter, childParam: NodegraphAPI.Parameter): ...
    @classmethod
    def _ensureParamForAttr(cls, parentParam: NodegraphAPI.Parameter, name: str, attr: PyFnAttribute.GroupAttribute) -> NodegraphAPI.Parameter: ...
    @classmethod
    def _setParamValue(cls, parentParam: NodegraphAPI.Parameter, childParam: NodegraphAPI.Parameter, attr: PyFnAttribute.GroupAttribute): ...
    @classmethod
    def clean(cls, parentParam: NodegraphAPI.Parameter, groupAttr: PyFnAttribute.GroupAttribute): ...
    @classmethod
    def update(cls, parentParam: NodegraphAPI.Parameter, groupAttr: PyFnAttribute.GroupAttribute): ...

def _DoInputRequests(interface, inputBehavior, inputPorts, graphState: NodegraphAPI.GraphState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class Layer(PyQt5.QtCore.QObject):
    def __init__(self, name: Incomplete | None = ..., visible: bool = ..., interactive: bool = ..., enabled: bool = ...) -> None: ...
    def applyWindowSpace(self): ...
    def applyWindowSpaceWithDropShadow(self, *args): ...
    def applyWorldSpace(self): ...
    def applyWorldSpaceWithDropShadow(self, *args): ...
    def enabled(self) -> bool: ...
    def focused(self) -> bool: ...
    def getWindowSize(self): ...
    def initializeGL(self): ...
    def interactive(self) -> bool: ...
    def layerStack(self) -> LayerStack: ...
    def mapFromQTLocalToWindow(self, qtX, qtY): ...
    def mapFromQTLocalToWorld(self, qtX, qtY): ...
    def mapFromWindowToQTLocal(self, winX, winY): ...
    def mapFromWindowToWorld(self, winX, winY): ...
    def mapFromWorldToQTLocal(self, worldX, worldY): ...
    def mapFromWorldToWindow(self, worldX, worldY): ...
    def name(self) -> str | None: ...
    def paintGL(self): ...
    def paintGLLeft(self): ...
    def paintGLRight(self): ...
    def processEvent(self, e) -> bool: ...
    def resizeGL(self): ...
    def setEnabled(self, flag: bool): ...
    def setFocused(self, flag: bool): ...
    def setInteractive(self, interactive: bool): ...
    def setLayerStack(self, v: LayerStack): ...
    def setName(self, n: str): ...
    def setStereo(self, s): ...
    def setVisible(self, visible: bool): ...
    def startDrag(self): ...
    def stereo(self) -> bool: ...
    def update(self): ...
    def visible(self) -> bool: ...

class LayerStack(PyQt5.QtWidgets.QOpenGLWidget):
    SPACE_MODE_WINDOW: ClassVar[int] = ...
    SPACE_MODE_WORLD: ClassVar[int] = ...
    STEREO_MODE_ANAGLYPH: ClassVar[int] = ...
    STEREO_MODE_MONO: ClassVar[bool] = ...
    STEREO_MODE_QUAD: ClassVar[int] = ...
    layerStack_scaleChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _LayerStack__delegateEvent(self, e): ...
    def _LayerStack__startDrag(self): ...
    def appendLayer(self, layer: Layer, stealFocus: bool = ...): ...
    def applyWindowSpace(self): ...
    def applyWindowSpaceWithDropShadow(self, screendx: float = ..., screendy: float = ...): ...
    def applyWorldSpace(self): ...
    def applyWorldSpaceWithDropShadow(self, screendx: float = ..., screendy: float = ...): ...
    def beginTextPainter(self): ...
    def contextMenuEvent(self, ev): ...
    def customEvent(self, event): ...
    def endTextPainter(self): ...
    def event(self, e): ...
    def firstPaintGL(self): ...
    def firstPaintGLLeft(self): ...
    def firstPaintGLRight(self): ...
    def focusLayer(self) -> Layer: ...
    def getClipPlanes(self) -> Tuple[float, float]: ...
    def getEyePoint(self): ...
    def getEyePointLeft(self): ...
    def getEyePointMain(self): ...
    def getEyePointRight(self): ...
    def getLayerByIndex(self, i: int) -> Layer: ...
    def getLayerByName(self, name: str) -> Layer: ...
    def getLayerCount(self) -> int: ...
    def getLayers(self) -> list[Layer]: ...
    def getMousePos(self) -> Tuple[int, int]: ...
    def getPseudoTopLevelWidget(self): ...
    def getTabletPressure(self): ...
    def getTabletTilt(self): ...
    def getViewScale(self) -> None: ...
    def getVisibleArea(self) -> Tuple[Tuple[float, float], Tuple[float, float]]: ...
    def getWindowSize(self) -> Tuple[int, int]: ...
    def getWorldBounds(self) -> Tuple[float, float, float, float] | None: ...
    def glDraw(self): ...
    def initializeGL(self): ...
    def insertLayer(self, layer: Layer, index: int): ...
    def isCapableOfNativeStereo(self): ...
    def isEraser(self): ...
    def isLayerFocused(self, layer): ...
    def mapFromQTLocalToWindow(self, qtX: float, qtY: float) -> Tuple[float, float]: ...
    def mapFromQTLocalToWorld(self, qtX: float, qtY: float) -> Tuple[float, float]: ...
    def mapFromWindowToQTLocal(self, winX: float, winY: float) -> Tuple[float, float]: ...
    def mapFromWindowToWorld(self, winX: float, winY: float) -> Tuple[float, float]: ...
    def mapFromWorldToQTLocal(self, worldX: float, worldY: float) -> Tuple[float, float]: ...
    def mapFromWorldToWindow(self, worldX: float, worldY: float) -> Tuple[float, float]: ...
    def paintGL(self): ...
    def removeLayer(self, layer: Layer): ...
    def renderText(self, *args): ...
    def reset(self): ...
    def resizeEvent(self, evt): ...
    def resizeGL(self, width, height): ...
    def setClipPlanes(self, nearClip: float, farClip: float): ...
    def setEyePoint(self, pt: None): ...
    def setEyePointLeft(self, pt): ...
    def setEyePointRight(self, pt): ...
    def setFocusLayer(self, layer: Layer, isFocused: bool = ...): ...
    def setStereoMode(self, stereoMode: int): ...
    def setTextColor(self, r, g, b, a: float = ...): ...
    def setViewLeft(self): ...
    def setViewMono(self): ...
    def setViewRight(self): ...
    def setViewScale(self, scale: None, final: bool = ...): ...
    def setVisibleArea(self, viewBounds): ...
    def stereoMode(self): ...
    def updateGL(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI as Nodes3DAPI
import UI4 as UI4
import Utils as Utils
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import Set, Tuple

class RenderSelectedToggle(ToolbarButton):
    def __init__(self, parent) -> None: ...
    def _RenderSelectedToggle__clicked(self): ...
    def _RenderSelectedToggle__updateCallback(self, *args, **kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
from UI4.FormMaster.NodeHints.Common2D import AddCommon2DToNodeHints as AddCommon2DToNodeHints, GetCapsuleRgbaDict as GetCapsuleRgbaDict, GetFgBgCombinerStringDict as GetFgBgCombinerStringDict, GetNormalizedCenterNumberDict as GetNormalizedCenterNumberDict
from typing import Set, Tuple

_NodeHints: dict
_NodeName: str



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtCore as QtCore
from typing import Set, Tuple

def ComputeAdjustedValue(startValue: int | float, delta: float, multiplier: float = ..., adjustmentMethod: int = ...) -> float: ...
def ComputeMultiplier(modifiers: PyQt5.QtCore.Qt.KeyboardModifiers) -> float: ...
def GetAdjustmentMethodFromString(methodStr: str) -> int: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyFnAttribute as FnAttribute
import Nodes3DAPI.Node3D as Node3D
import NodegraphAPI as NodegraphAPI
from Nodes3DAPI.GenericAssign import GenericAssign as GenericAssign
from typing import ClassVar, Set, Tuple

_ParamHints: dict
_Parameter_XML: str
_baseXML: None

class CameraImagePlaneCreate(GenericAssign):
    _CameraImagePlaneCreate__parsedArgTree: ClassVar[None] = ...
    def __init__(self) -> None: ...
    def _filterAttrList(self, graphState: NodegraphAPI.GraphState, attrList): ...
    def _getIncomingSceneOpAndLocation(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, transaction): ...
    def addParameterHints(self, attrName, inputDict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import MediaCacheHandler.DiskUtil as DiskUtil
import MediaCacheHandler.ImageUtil as ImageUtil
from _typeshed import Incomplete
from typing import Set, Tuple

def CopyElementsToMediaCache(elementList, deletionCB: Incomplete | None = ..., elementProgressCB: Incomplete | None = ..., fileProgressCB: Incomplete | None = ..., logTiming: bool = ...): ...
def DeleteElementFromMediaCache(localMediaElementDir): ...
def GetElementProportionLocal(element): ...
def GetElementsSafeForDeletion(excludeElementDirs: Incomplete | None = ..., initialLocalElements: Incomplete | None = ...): ...
def GetLocalElements(directory: Incomplete | None = ...): ...
def GetMediaCacheFreeSpaceB(): ...
def GetMediaCacheSizeB(): ...
def GetTargetMediaCacheSizeB(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import Core as Core, DiskUtil as DiskUtil, ImageUtil as ImageUtil, KatanaUtil as KatanaUtil
from MediaCacheHandler.Core import CopyElementsToMediaCache as CopyElementsToMediaCache, DeleteElementFromMediaCache as DeleteElementFromMediaCache, GetElementProportionLocal as GetElementProportionLocal, GetElementsSafeForDeletion as GetElementsSafeForDeletion, GetLocalElements as GetLocalElements, GetMediaCacheFreeSpaceB as GetMediaCacheFreeSpaceB, GetMediaCacheSizeB as GetMediaCacheSizeB, GetTargetMediaCacheSizeB as GetTargetMediaCacheSizeB
from typing import Set, Tuple



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtGui as QtGui
import UI4.Widgets.SceneGraphView.SceneGraphViewColumn
from _typeshed import Incomplete
from typing import Set, Tuple

class ContextMenuEvent(PyQt5.QtGui.QContextMenuEvent):
    def __init__(self, event, locationPath: Incomplete | None = ..., topLevelLocationPath: Incomplete | None = ..., selectedLocations: Incomplete | None = ..., sceneGraphColumn: Incomplete | None = ...) -> None: ...
    def getLocationPath(self) -> str | None: ...
    def getSceneGraphColumn(self) -> SceneGraphColumn[UI4.Widgets.SceneGraphView.SceneGraphViewColumn.SceneGraphColumn]: ...
    def getSelectedLocations(self) -> list[tuple]: ...
    def getTopLevelLocationPath(self) -> str | None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class ExpressionEditDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, policy, parent: Incomplete | None = ...) -> None: ...
    def _ExpressionEditDialog__disconnectFromPolicy(self): ...
    def _ExpressionEditDialog__updateExpr(self): ...
    def _ExpressionEditDialog__valueChangedEvent(self, event): ...
    def accept(self): ...
    def closeEvent(self, event): ...
    def reject(self): ...
    def __del__(self) -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Any, Set, Tuple, overload

RETIME_FREEZE: int
RETIME_MIRROR: int
RETIME_REPEAT: int

def cfit(value: object, oldmin: object, oldmax: object, newmin: object, newmax: object) -> Any: ...
def clamp(value: object, min: object, max: object) -> Any: ...
def fit(value: object, oldmin: object, oldmax: object, newmin: object, newmax: object) -> Any: ...
def ifelse(expr: object, a: object, b: object) -> Any: ...
def isfinite(value: float) -> bool: ...
def isinf(value: float) -> bool: ...
def isnan(value: float) -> bool: ...
def lerp(t: object, min: object, max: object) -> Any: ...
def noise(x: float, y: float = ..., z: float = ..., w: float = ...) -> float: ...
def randval(min: float, max: float, seed: int) -> float: ...
def retime(frame: float, start: float, end: float, inMode: object, outMode: object) -> float: ...
@overload
def smoothstep(value: object) -> Any: ...
@overload
def smoothstep(easein, easeout) -> Any: ...
def snoise(x: float, y: float = ..., z: float = ..., w: float = ...) -> float: ...
def softcfit(value: object, oldmin: object, oldmax: object, newmin: object, newmax: object) -> Any: ...
def stablehash(str: str) -> int: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import Nodes3DAPI as Nodes3DAPI
import Utils as Utils
from Utils.Decorators import deprecated as deprecated
from _typeshed import Incomplete
from typing import Set, Tuple

def GenerateXMLFile(**kwargs): ...
def GetAutoMkproxy(node: NodegraphAPI.Node): ...
def GetFarmSettings(node: NodegraphAPI.Node): ...
def GetSortedDependencies(nodeList: Incomplete | None = ..., syncAllOutputPorts: bool = ..., includeInternalDeps: bool = ..., includeBypassed: bool = ...) -> list[dict]: ...
def GetSortedDependencyList(nodeList: Incomplete | None = ..., syncAllOutputPorts: bool = ..., includeInternalDeps: bool = ..., includeBypassed: bool = ...): ...
def GetVersionSync(node: NodegraphAPI.Node): ...
def WriteFarmFile(fileName, outlineString): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.Bridge
from UI4.Widgets.SceneGraphView.ItemDelegates.BaseItemDelegate import BaseItemDelegate as BaseItemDelegate
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class StateItemDelegate(StateItemDelegateMixin, BaseItemDelegate):
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...

class StateItemDelegateMixin:
    DefaultColumnWidth: ClassVar[int] = ...
    def __init__(self, bridge: Bridge[UI4.Widgets.SceneGraphView.Bridge.Bridge], treeWidget: PyQt5.QtWidgets.QTreeWidget, parent: Incomplete | None = ...) -> None: ...
    def _updateColumnSize(self): ...
    def addState(self, name: str, icon: Incomplete | None = ..., text: Incomplete | None = ...): ...
    def calculateItemState(self, option, index): ...
    def canChangeSelection(self, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtCore.QEvent) -> bool: ...
    def editorEvent(self, event: PyQt5.QtCore.QEvent, itemModel: PyQt5.QtCore.QAbstractItemModel, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex) -> bool: ...
    def getItemStates(self): ...
    def initStyleOption(self, option: PyQt5.QtWidgets.QStyleOptionViewItem, index: PyQt5.QtCore.QModelIndex): ...
    def isValidState(self, name: str) -> bool: ...
    def modifyItemState(self, item: PyQt5.QtWidgets.QTreeWidgetItem, index: PyQt5.QtCore.QModelIndex, event: PyQt5.QtGui.QMouseEvent) -> bool: ...
    def removeState(self, name: str): ...
    def setItemState(self, state: str, locationPath: str): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Widgets.ToolbarButton import ToolbarButton as ToolbarButton
from typing import ClassVar, Set, Tuple

class NodeStateFilterFrame(PyQt5.QtWidgets.QFrame):
    def __init__(self, parent) -> None: ...
    def _NodeStateFilterFrame__onNodeViewChanged(self, _prevViewNode, currViewNode): ...
    def _NodeStateFilterFrame__onShowHideFilters(self): ...

class _ToggleFrame(PyQt5.QtWidgets.QFrame):
    class _ToggleFrame__Toggle(tuple):
        _field_defaults: ClassVar[dict] = ...
        _fields: ClassVar[tuple] = ...
        _fields_defaults: ClassVar[dict] = ...
        def __init__(self, _cls, name, label) -> None: ...
        def _asdict(self): ...
        @classmethod
        def _make(cls, iterable): ...
        def _replace(self, _self, **kwds): ...
        def __getnewargs__(self): ...
        @property
        def label(self): ...
        @property
        def name(self): ...
    _ToggleFrame__buttonStyle: ClassVar[str] = ...
    _ToggleFrame__togglesByPref: ClassVar[dict] = ...
    def __init__(self, parent) -> None: ...
    @staticmethod
    def _ToggleFrame__onButtonClicked(button): ...
    def _ToggleFrame__onPrefChanged(self, _eventType, _eventID, prefKey, prefValue): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import UI4.Util.ExternalTools as ExternalTools
import UI4.Util.FileHelpers as FileHelpers
import PyQt5.QtWidgets
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import RenderingAPI as RenderingAPI
import UI4.App.Tabs as Tabs
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import ClassVar, Set, Tuple

KATANA_ROOT: str
NODES_ROOT: str
PROJECTS_XML_PATH: str
SCENES_ROOT: str
THUMBS_ROOT: str

class ExampleProjectsTab(BaseTab):
    def __init__(self, parent) -> None: ...
    def _ExampleProjectsTab__constructLayout(self): ...
    def _ExampleProjectsTab__on_anchorClicked(self, url): ...
    def _ExampleProjectsTab__on_itemSelectionChanged(self): ...
    def openScene(self, index: int = ...): ...
    def showProject(self, project: Project): ...
    def showSection(self, section: Section): ...

class Project:
    def __init__(self, title, description, thumbnail, scenes, nodes) -> None: ...

class ProjectDataBrowserWidget(PyQt5.QtWidgets.QTextBrowser):
    PROJECT_HTML: ClassVar[str] = ...
    PROJECT_STYLESHEET: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def clearDescription(self): ...
    def showProject(self, project: Project): ...

class ProjectListTreeWidget(PyQt5.QtWidgets.QTreeWidget):
    def __init__(self) -> None: ...
    def populate(self, sectionTitles: list[str], sections: dict[str, Section]): ...

class ProjectScene:
    def __init__(self, renderer, path) -> None: ...

class Section:
    def __init__(self, title, projectTitles) -> None: ...

def ParseProjectsXml(filename: str) -> tuple[list, dict, dict]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4Browser.BrowserFiltering as BrowserFiltering
import QT4Browser.BrowserSettings as BrowserSettings
import QT4Browser.FileInfo as FileInfo
import PyQt5.QtCore
import PyQt5.QtWidgets
import QT4Browser.FileInfo
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import re
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class FileBrowser(PyQt5.QtWidgets.QFrame):
    accept: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args, **kargs) -> None: ...
    def _FileBrowser__connect(self): ...
    def _FileBrowser__dirFilterChanged(self, filterText): ...
    def _FileBrowser__doubleclick_filename(self, fileNameQStr): ...
    def _FileBrowser__fileFilterChanged(self, filterText): ...
    def _FileBrowser__locationEntered(self): ...
    def _FileBrowser__setup_children(self): ...
    def _FileBrowser__setup_layout(self): ...
    def _FileBrowser__singleclick_filename(self, fileNameQStr): ...
    def canAccept(self): ...
    def commitCurrentLocation(self): ...
    def currentLocation(self): ...
    def dirsOnly(self): ...
    def fileFilter(self): ...
    def hideEvent(self, event): ...
    def loadSettings(self): ...
    def saveSettings(self): ...
    def selectFileFilter(self, filterText): ...
    def setCurrentLocation(self, loc): ...
    def setDirFilter(self, filterText): ...
    def setDirsOnly(self, dirsOnly): ...
    def setFileFilter(self, filterText): ...
    def setPreview(self, preview): ...
    def setShowHidden(self, flag): ...
    def setShowSequence(self, flag): ...
    def setToDefaultLocation(self): ...
    def showEvent(self, event): ...
    def showHidden(self): ...
    def showSequence(self): ...

class _DirectoryCombo(PyQt5.QtWidgets.QFrame):
    activated: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    back_list: ClassVar[list] = ...
    link_list: ClassVar[list] = ...
    recent_list: ClassVar[list] = ...
    ss_list: ClassVar[list] = ...
    def __init__(self, *args) -> None: ...
    def _DirectoryCombo__addToRecent(self, location): ...
    def _DirectoryCombo__back_clicked(self): ...
    def _DirectoryCombo__item_completing(self, dirQStr): ...
    def _DirectoryCombo__item_selected(self, dirQStr): ...
    def _DirectoryCombo__up_clicked(self): ...
    def currentLocation(self): ...
    def getRecentList(self): ...
    def refresh(self): ...
    def setCurrentLocation(self, location, recordHistory: bool = ..., noRefresh: bool = ...): ...
    def setRecentList(self, rlist, setBackList: bool = ...): ...

class _EatEnterQComboBox(PyQt5.QtWidgets.QComboBox):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def event(self, evt): ...

class _EatEnterWCursorMangementQComboBox(_EatEnterQComboBox):
    def __init__(self, *args, **kargs) -> None: ...
    def _EatEnterWCursorMangementQComboBox__activated(self, index): ...
    def setCurrentIndex(self, index): ...

class _FileListModel(QT4Browser.FileInfo.AbstractFileTableModel):
    FullPathRole: ClassVar[int] = ...
    def __init__(self, *args) -> None: ...
    def _FileListModel__applyFilter(self): ...
    def currentLocation(self): ...
    def data(self, index, role): ...
    def dirFilter(self): ...
    def dirsOnly(self): ...
    def fileFilter(self): ...
    def refresh(self): ...
    def setCurrentLocation(self, location): ...
    def setDirFilter(self, filterText): ...
    def setDirsOnly(self, dirsOnly): ...
    def setFileFilter(self, filterText): ...
    def setShowHidden(self, flag): ...
    def setShowSequence(self, flag): ...
    def showHidden(self): ...
    def showSequence(self): ...

class _FileListView(QT4Browser.FileInfo.FileTableView):
    clicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    currentChangedSignal: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    doubleClicked: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _FileListView__itemClicked(self, index): ...
    def _FileListView__itemDoubleClicked(self, index): ...
    def _modelReset(self): ...
    def currentChanged(self, current, previous): ...
    def event(self, evt): ...
    def selectionChanged(self, selected, deselected): ...

class _PathField(PyQt5.QtWidgets.QLineEdit):
    _PathField__env_var_re: ClassVar[re.Pattern] = ...
    selectionChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    def _PathField__getCompletionText(self): ...
    def _PathField__refresh(self): ...
    def _PathField__textChanged(self, newTextQStr): ...
    def currentLocation(self): ...
    def dirFilter(self): ...
    def event(self, evt): ...
    def fileFilter(self): ...
    def paintEvent(self, evt): ...
    def setCurrentLocation(self, location): ...
    def setDirFilter(self, filterText): ...
    def setDirName(self, dirName): ...
    def setDirsOnly(self, on): ...
    def setFileFilter(self, filterText): ...
    def setShowFullPath(self, on): ...
    def setShowHidden(self, flag): ...
    def setShowSequence(self, flag): ...
    def showHidden(self): ...
    def showSequence(self): ...
    def str(self): ...

class _PreviewPane(PyQt5.QtWidgets.QLabel):
    def __init__(self, fb, cb, parent) -> None: ...
    def _PreviewPane__callCallback(self, size): ...
    def resizeEvent(self, e): ...
    def setLocation(self, location): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import AssetAPI as AssetAPI
import UI4.FormMaster.EnableableParameterPolicy as EnableableParameterPolicy
import UI4.FormMaster.HintsDelegate as HintsDelegate
import UI4.Util.ManipulatorManager as ManipulatorManager
import UI4.FormMaster.ParameterPolicy as ParameterPolicy
import PyQt5.QtCore
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.Conditional
import PyQt5.QtCore as QtCore
from UI4.FormMaster.NodeHints.Common2D import GetBoundsParamDict as GetBoundsParamDict
from typing import ClassVar, Set, Tuple

_NodeHints: dict

class ImageWriteExtensionOp(QT4FormWidgets.Conditional.ConditionalVisibilityOpBase):
    conditionalStateEval: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def _ImageWriteExtensionOp__operandChanged(self, state): ...
    def checkState(self): ...
    def freeze(self): ...
    def getValue(self, policyName): ...
    def thaw(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class WheelEventIgnoringTabBar(PyQt5.QtWidgets.QTabBar):
    def wheelEvent(self, wheelEvent: PyQt5.QtGui.QWheelEvent): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import ConfigurationAPI_cmodule as Configuration
import UI4.Util.DrawState as DrawState
import Nodes3DAPI as Nodes3DAPI
import PyOpenColorIO as OCIO
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SceneGraphView.SceneGraphViewIconManager as SceneGraphViewIconManager
import UI4 as UI4
import UI4.Tabs.Catalog
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import RenderManager as RenderManager
from UI4.App.KeyboardShortcutManager.KeyboardShortcutManager import GetShortcutForKeyEvent as GetShortcutForKeyEvent
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Tabs.Monitor.CommentWidgets import CatalogItemCommentEditor as CatalogItemCommentEditor
from UI4.Tabs.Monitor.DisplayDetailsWidgets import DisplayChannelsLabel as DisplayChannelsLabel, DisplayExposureLabel as DisplayExposureLabel, DisplayScaleLabel as DisplayScaleLabel, DisplayVisualizationLabel as DisplayVisualizationLabel, InputColorspaceLabel as InputColorspaceLabel, LayerSelectionLabel as LayerSelectionLabel, MatteMultLabel as MatteMultLabel, SwipeModeLabel as SwipeModeLabel
from UI4.Tabs.Monitor.Manipulators import AddManipulatorMenuActions as AddManipulatorMenuActions
from UI4.Tabs.Monitor.MonitorWidget import MonitorWidget as MonitorWidget
from UI4.Widgets.HorizontalDivider import HorizontalDivider as HorizontalDivider
from UI4.Widgets.RolloverPixmap import RolloverPixmap
from typing import ClassVar, Set, Tuple

_minimumWindowSize: int
secondaryClientKey: int

class CloseBoxButton(RolloverPixmap, PyQt5.QtWidgets.QPushButton):
    def __init__(self, parent) -> None: ...

class MonitorPanel(BaseTab):
    _MonitorPanel__AlternateDefaultAovShortcutID: ClassVar[str] = ...
    _MonitorPanel__ShowNextAovShortcutID: ClassVar[str] = ...
    _MonitorPanel__ShowPreviousAovShortcutID: ClassVar[str] = ...
    _MonitorPanel__SwapBuffersShortcutID: ClassVar[str] = ...
    def __init__(self, *args) -> None: ...
    def _MonitorPanel__alternateDefaultAovCallback(self): ...
    def _MonitorPanel__buildManipulatorMenu_CB(self, menu): ...
    def _MonitorPanel__catalogWidgetA_catalogItemDropped_CB(self, item): ...
    def _MonitorPanel__catalogWidgetB_catalogItemDropped_CB(self, item): ...
    def _MonitorPanel__catalog_clientSlotUpdate_CB(self, _eventType: str | None, eventID: typing.Hashable): ...
    def _MonitorPanel__commentsButtonClicked_CB(self): ...
    def _MonitorPanel__createCatalogArea(self): ...
    def _MonitorPanel__createCatalogInfoBar(self): ...
    def _MonitorPanel__createCommentToolbar(self): ...
    def _MonitorPanel__createLayerToolbarWidget(self): ...
    def _MonitorPanel__createOverlayToolbar(self): ...
    def _MonitorPanel__createStereoToolbar(self): ...
    def _MonitorPanel__createTopIconArea(self): ...
    def _MonitorPanel__deleteOverlayButton_released_CB(self): ...
    def _MonitorPanel__deleteUnderlayButton_released_CB(self): ...
    def _MonitorPanel__displayItemsChanged_CB(self): ...
    def _MonitorPanel__displayMenuAboutToShow_CB(self): ...
    def _MonitorPanel__drawStateUpdated_CB(self): ...
    def _MonitorPanel__editTransformEnabled_CB(self): ...
    def _MonitorPanel__editTransformErrored_CB(self, value, message): ...
    def _MonitorPanel__editTransformToggled_CB(self): ...
    @staticmethod
    def _MonitorPanel__getShortcutAsString(actionID: str) -> str: ...
    def _MonitorPanel__imageModeChanged_CB(self): ...
    def _MonitorPanel__linkButton_clicked_CB(self): ...
    def _MonitorPanel__makeConnections(self): ...
    def _MonitorPanel__manipulatorToggled_CB(self): ...
    def _MonitorPanel__maskChangedSecondary_CB(self): ...
    def _MonitorPanel__maskChanged_CB(self): ...
    def _MonitorPanel__monitorAddToolbar_CB(self, toolbar, layer): ...
    def _MonitorPanel__monitorPopToolbar_CB(self, toolbar, layer): ...
    def _MonitorPanel__monitorRemoveToolbar_CB(self, toolbar, layer): ...
    def _MonitorPanel__monitorRoiVisibilityChanged_CB(self): ...
    def _MonitorPanel__monitor_drawStateLinkUpdate_CB(self): ...
    def _MonitorPanel__onPrefChanged(self, eventType: str | None, eventID: typing.Hashable, prefKey: str, prefValue: object): ...
    def _MonitorPanel__on_overlayModeCombobox_activated(self, text): ...
    def _MonitorPanel__on_scenegraphMask_visibilityFollowsWorkingSetChanged(self, eventType, eventID, visibilityFollowsWorkingSet): ...
    def _MonitorPanel__overlayButtonClicked_CB(self): ...
    def _MonitorPanel__overlayChanged_CB(self): ...
    def _MonitorPanel__overlayCheckBox_stateChanged_CB(self, state): ...
    def _MonitorPanel__overlayThumbnail_catalogItemDropped_CB(self, item): ...
    def _MonitorPanel__populateMenuBar(self): ...
    def _MonitorPanel__probeButtonClicked_CB(self): ...
    def _MonitorPanel__renderColumnToggled_CB(self): ...
    def _MonitorPanel__renderWorkingSetStatusChanged(self, isActive): ...
    def _MonitorPanel__roiCombo_roiVisibilityChanged_CB(self): ...
    def _MonitorPanel__showNextAovCallback(self): ...
    def _MonitorPanel__showPreviousAovCallback(self): ...
    def _MonitorPanel__stereoButtonClicked_CB(self): ...
    def _MonitorPanel__stereoModePopup_activated_CB(self, text): ...
    def _MonitorPanel__swapBuffersPressCallback(self): ...
    def _MonitorPanel__syncPanZoom_CB(self, eyePoint, viewScale, srcWidget): ...
    def _MonitorPanel__toolbarChanged_CB(self, toolbar): ...
    def _MonitorPanel__underlayCheckBox_stateChanged_CB(self, state): ...
    def _MonitorPanel__underlayThumbnail_catalogItemDropped_CB(self, item): ...
    def _MonitorPanel__updateManipulatorVisibility_CB(self): ...
    def _MonitorPanel__updateModeLabels(self): ...
    def _MonitorPanel__updatePixelProbeVisibility_CB(self): ...
    def getEmbeddedCatalogTab(self) -> UI4.Tabs.Catalog.CatalogPanel: ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def getMonitorWidget(self) -> MonitorWidget: ...
    @staticmethod
    def registerKeyboardShortcuts(): ...
    def swapCatalogView(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI
import Utils as Utils
import PyFnGeolibServices.XFormUtil as XFormUtil
from _typeshed import Incomplete
from typing import Set, Tuple

_TransformParameterHints: dict
_xyz: list

def CanOverrideTransform(node: NodegraphAPI.Node, attrName): ...
def FindOverrideParameterTransform(node: NodegraphAPI.Node, path, attrName, time, index: Incomplete | None = ..., editable: bool = ...): ...
def GetEnableableNodesWithTransforms(): ...
def GetRotateAttr(attr, param, frameTime): ...
def GetRotateXAttr(attr, param, frameTime): ...
def GetRotateYAttr(attr, param, frameTime): ...
def GetRotateZAttr(attr, param, frameTime): ...
def GetScaleAttr(attr, param, frameTime): ...
def GetTransformAttr(attr, param, frameTime): ...
def GetTransformAttrWithMotionUsingGraphState(param, graphState: NodegraphAPI.GraphState): ...
def GetTransformAttr_WithMotion(attr, param, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset: float = ...): ...
def GetTransformParameterAttrsForNodeTypeBuilder(): ...
def GetTransformParameterHints(): ...
def GetTransformXML(): ...
def GetTranslateAttr(attr, param, frameTime): ...
def PushInteractiveTransform(attr, scale, rotate, translate, _time): ...
def ResetTransformParams(param, time): ...
def SetOverrideTransform(node: NodegraphAPI.Node, path, attrName, time, attrData, index: Incomplete | None = ..., *args, **kwargs): ...
def SetTransformParamsSRTXYZ(param, scale, rotate, translate, time): ...
def _AppendMatrix(attr, matrixParam, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...
def _AppendRotate(attr, param, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...
def _AppendRotateX(attr, param, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...
def _AppendRotateY(attr, param, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...
def _AppendRotateZ(attr, param, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...
def _AppendScale(attr, prm, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...
def _AppendTransformItem(inGroup, itemName, itemAttr): ...
def _AppendTranslate(attr, prm, shutterOpenTime, timeWindowDuration, timeNumSamples, sampleOffset): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
from typing import Set, Tuple

class RenderNodeReferencePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, nodeName, portName) -> None: ...
    def getExpressionNamespace(self): ...
    def getExpressionReference(self): ...
    def getName(self): ...
    def getType(self): ...
    def getValue(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import NodegraphAPI as NodegraphAPI
import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from typing import Set, Tuple

class GroupInteractionLayer(QT4GLLayerStack.LayerStack.Layer):
    def __init__(self, *args, **kwargs) -> None: ...
    def _GroupInteractionLayer__buildMenus(self): ...
    def _GroupInteractionLayer__deletePortCallback(self): ...
    def _GroupInteractionLayer__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _GroupInteractionLayer__renamePortCallback(self): ...
    def processEvent(self, event): ...

def smoothstep(x): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.App as App
import AttributeEditorTreeWidget
import UI4.FormMaster as FormMaster
import KatanaResources as KatanaResources
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import ResourceFiles as ResourceFiles
import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import UI4 as UI4
import UI4.FormMaster.Editors.NodeGroup
import Utils as Utils
import UI4.Widgets as Widgets
from ResourceFiles.IconManager import ResourceManager as ResourceManager
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AttributeEditorNodeGroupFormWidget(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _AttributeEditorNodeGroupFormWidget__changeExclusivity(self, event): ...
    def _AttributeEditorNodeGroupFormWidget__checkForOverlappingAttributes(self, selectedAttributeDict, selectedSgLocs): ...
    def _AttributeEditorNodeGroupFormWidget__contentsMousePressCallback(self, item, col): ...
    def _AttributeEditorNodeGroupFormWidget__contextMenuCallback(self, pos): ...
    def _AttributeEditorNodeGroupFormWidget__copyToCommonRoot(self): ...
    def _AttributeEditorNodeGroupFormWidget__copyToScenegraphSelection(self): ...
    def _AttributeEditorNodeGroupFormWidget__deleteSelectedOverrides(self): ...
    def _AttributeEditorNodeGroupFormWidget__doMoveOrCopyActionToCommonRoot(self, fcn, description): ...
    def _AttributeEditorNodeGroupFormWidget__doMoveOrCopyActionToScenegraphSelection(self, fcn, description): ...
    def _AttributeEditorNodeGroupFormWidget__findCommonRootOfSelection(self): ...
    def _AttributeEditorNodeGroupFormWidget__getSelectedAttributeDict(self): ...
    def _AttributeEditorNodeGroupFormWidget__goToSelectedLocations(self): ...
    def _AttributeEditorNodeGroupFormWidget__idle_callback(self, *args, **kwargs): ...
    def _AttributeEditorNodeGroupFormWidget__ignoreSelectedOverrides(self, flag: bool = ...): ...
    def _AttributeEditorNodeGroupFormWidget__isSelectionIgnored(self): ...
    def _AttributeEditorNodeGroupFormWidget__itemSelectionChangedCB(self): ...
    def _AttributeEditorNodeGroupFormWidget__linkClickedCallback(self, link: str): ...
    def _AttributeEditorNodeGroupFormWidget__moveToCommonRoot(self): ...
    def _AttributeEditorNodeGroupFormWidget__moveToScenegraphSelection(self): ...
    def _AttributeEditorNodeGroupFormWidget__node_setByPassedCB(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _AttributeEditorNodeGroupFormWidget__overrideCreatedCallback(self, eventId, node: NodegraphAPI.Node): ...
    def _AttributeEditorNodeGroupFormWidget__parameter_finalizedValueCB(self, eventType, eventID, **kwargs): ...
    def _AttributeEditorNodeGroupFormWidget__timeChangeCB(self, *args, **kwawgs): ...
    def _AttributeEditorNodeGroupFormWidget__unignoreSelectedOverrides(self): ...
    def _AttributeEditorNodeGroupFormWidget__updateListView(self, selectLocs: Incomplete | None = ...): ...
    def _freeze(self): ...
    def _thaw(self): ...
    def keyPressEvent(self, event): ...
    def __del__(self) -> None: ...

class AttributeEditorTreeWidget(PyQt5.QtWidgets.QTreeWidget):
    class Attribute(tuple):
        _field_defaults: ClassVar[dict] = ...
        _fields: ClassVar[tuple] = ...
        _fields_defaults: ClassVar[dict] = ...
        def __init__(self, _cls, attrType, name, data, tupleSize, sceneGraphLocationPath, hints) -> None: ...
        def _asdict(self): ...
        @classmethod
        def _make(cls, iterable): ...
        def _replace(self, _self, **kwds): ...
        def __getnewargs__(self): ...
        @property
        def attrType(self): ...
        @property
        def data(self): ...
        @property
        def hints(self): ...
        @property
        def name(self): ...
        @property
        def sceneGraphLocationPath(self): ...
        @property
        def tupleSize(self): ...
    ignoreStateChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, attributeEditorNode: NodegraphAPI.Node, parent: Incomplete | None = ...) -> None: ...
    def _AttributeEditorTreeWidget__decodeDraggedAttribute(self, mimeData: PyQt5.QtCore.QMimeData) -> AttributeEditorTreeWidget.Attribute | None: ...
    def dragEnterEvent(self, event: PyQt5.QtGui.QDragEnterEvent): ...
    def dragMoveEvent(self, event: PyQt5.QtGui.QDragMoveEvent): ...
    def dropEvent(self, event: PyQt5.QtGui.QDropEvent): ...
    def keyPressEvent(self, event: PyQt5.QtGui.QKeyEvent): ...

class OverrideItem(PyQt5.QtWidgets.QTreeWidgetItem):
    def __init__(self, parent, name, ignored, overrideNode, index: int = ...) -> None: ...
    def getIndex(self): ...
    def getMaxIndex(self): ...
    def getParameter(self): ...
    def isIgnored(self): ...
    def makeSelected(self, selected): ...
    def setIndex(self, index): ...
    def usesSlider(self): ...

class PopupEditor(PyQt5.QtWidgets.QFrame):
    def __init__(self) -> None: ...
    def clearTarget(self): ...
    def setTarget(self, parentPolicy, param, widgetFactory): ...

class PopupSlider(PyQt5.QtWidgets.QFrame):
    def __init__(self) -> None: ...
    def _PopupSlider__valueChangeCallback(self, value): ...
    def clearTarget(self): ...
    def hideEvent(self, e): ...
    def setTarget(self, minValue, maxValue, curValue, callbackFnc): ...
    def showEvent(self, e): ...

class ScenegraphLocationItem(PyQt5.QtWidgets.QTreeWidgetItem):
    def __init__(self, path, node: NodegraphAPI.Node, attrs, parent) -> None: ...
    def isIgnored(self): ...
    def makeSelected(self, selected): ...
    def setPixmap(self, index, pixmap): ...
    def updateSelection(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
import PyFnGeolibProducers
from typing import Any, Set, Tuple

class RendererPlugin:
    def __init__(self, *args, **kwargs) -> None: ...
    def configureDiskRenderOutputProcess(self, outputName: str, outputPath: str, renderMethodName: str, frameTime: float) -> PyFnAttribute.GroupAttribute: ...

def GetPlugin(pluginName: str, producer: PyFnGeolibProducers.GeometryProducer) -> Any: ...
def ReleaseManager() -> None: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtGui
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from typing import Set, Tuple

class WideEditDialog(PyQt5.QtWidgets.QDialog):
    def __init__(self, policy, factory) -> None: ...
    def showEvent(self, event: PyQt5.QtGui.QShowEvent): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import PyUtilModule.Documentation as Documentation
import KatanaResources as KatanaResources
import MachineInfo as MachineInfo
import NodegraphAPI as NodegraphAPI
import Nodes3DAPI as Nodes3DAPI
import PyUtilModule as PyUtilModule
import PyQt5.QtGui as QtGui
import PyUtilModule.RenderManager.RenderGlobals as RenderGlobals
import PyUtilModule.RenderManager as RenderManager
from . import KatanaPrefsObject as KatanaPrefsObject, PrefNames as PrefNames
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from typing import Set, Tuple

class __AvailableFonts:
    def __init__(self, codeFontsOnly: bool = ...) -> None: ...
    def __iter__(self) -> __AvailableFonts: ...
    def __next__(self) -> tuple: ...

def GetAvailableFontFamilies(codeFontsOnly: bool = ...) -> list[str]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from PyUtilModule.VirtualKatana import Widgets as Widgets
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import ClassVar, Set, Tuple

PluginRegistry: list

class ParameterFindAndReplacePanel(BaseTab):
    MATCHTYPE_CONTAINS: ClassVar[int] = ...
    MATCHTYPE_EXACTMATCH: ClassVar[int] = ...
    MATCHTYPE_REGEX: ClassVar[int] = ...
    NODE_NAMES: ClassVar[int] = ...
    PARAMS_ALL: ClassVar[int] = ...
    PARAMS_WITHOUT_EXPRESSIONS: ClassVar[int] = ...
    PARAMS_WITHOUT_EXPRESSION_AND_NODE_NAMES: ClassVar[int] = ...
    PARAMS_WITH_EXPRESSIONS: ClassVar[int] = ...
    _ParameterFindAndReplacePanel__matchTypeDisplayNames: ClassVar[dict] = ...
    _ParameterFindAndReplacePanel__scopeTypeDisplayNames: ClassVar[dict] = ...
    def __init__(self, parent) -> None: ...
    def _ParameterFindAndReplacePanel__clearButtonClicked(self): ...
    def _ParameterFindAndReplacePanel__contextMenuRequest(self, pos): ...
    def _ParameterFindAndReplacePanel__copyResultList(self): ...
    def _ParameterFindAndReplacePanel__discardNodesOfSelectedType(self): ...
    def _ParameterFindAndReplacePanel__discardNodesWithSelectedParent(self): ...
    def _ParameterFindAndReplacePanel__discardParametersOfSelectedName(self): ...
    def _ParameterFindAndReplacePanel__discardSelectedNode(self): ...
    def _ParameterFindAndReplacePanel__editParamsForSelected(self): ...
    def _ParameterFindAndReplacePanel__findButtonClicked(self): ...
    def _ParameterFindAndReplacePanel__findNonSelectedNodeChildren(self, node: NodegraphAPI.Node, nodeList): ...
    def _ParameterFindAndReplacePanel__interrupt(self): ...
    def _ParameterFindAndReplacePanel__keepOnlyNodesOfSelectedType(self): ...
    def _ParameterFindAndReplacePanel__keepOnlyNodesWithSelectedParent(self): ...
    def _ParameterFindAndReplacePanel__keepOnlyParametersOfSelectedName(self): ...
    def _ParameterFindAndReplacePanel__keepOnlySelectedNode(self): ...
    def _ParameterFindAndReplacePanel__matches(self, value, searchText, matchType): ...
    def _ParameterFindAndReplacePanel__replace(self, value, searchText, replaceText, matchType): ...
    def _ParameterFindAndReplacePanel__replaceButtonClicked(self): ...
    def _ParameterFindAndReplacePanel__replaceTextChanged(self, text): ...
    def _ParameterFindAndReplacePanel__searchTextChanged(self, text): ...
    def _ParameterFindAndReplacePanel__updateResultLabel(self): ...
    def _ParameterFindAndReplacePanel__walkParameter(self, param, searchText, parameterFilter, matchType): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtWidgets as QtWidgets
from UI4.App.KeyboardShortcutManager.KeyboardShortcutManagerMixin import KeyboardShortcutManagerMixin as KeyboardShortcutManagerMixin, KeyboardShortcutManagerMixinMetaclass as KeyboardShortcutManagerMixinMetaclass
from typing import Set, Tuple

class BaseFrame(PyQt5.QtWidgets.QFrame, KeyboardShortcutManagerMixin): ...

class BaseMainWindow(PyQt5.QtWidgets.QMainWindow, KeyboardShortcutManagerMixin): ...

class BaseWidget(PyQt5.QtWidgets.QWidget, KeyboardShortcutManagerMixin): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.AbstractTransform as AbstractTransform
import PyFnAttribute as FnAttribute
from Nodes3DAPI.AbstractTransform import AT as AT
from typing import Set, Tuple

def GetJackGeometryAttr(scale: float = ...): ...
def GetPointerGeometryAttr(scale: float = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

class UniqueListDict:
    def __init__(self, name: Incomplete | None = ..., defaultKey: Incomplete | None = ..., pairList: list = ...) -> None: ...
    def append(self, pair): ...
    def get(self, key): ...
    def getDefault(self): ...
    def getName(self): ...
    def next(self, pos): ...
    def setDefault(self, defaultKey): ...
    def setName(self, name): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import PyUtilModule.RenderManager as RenderManager
import UI4.Widgets.StopButton
import Utils as Utils
from UI4.Widgets.StopButton import SimpleStopWidget as SimpleStopWidget
from typing import Set, Tuple

class CatalogStopWidget(UI4.Widgets.StopButton.SimpleStopWidget):
    def __init__(self, parent) -> None: ...
    def _CatalogStopWidget__catalog_itemDelete_CB(self, eventType, eventID, item, **kwargs): ...
    def _CatalogStopWidget__catalog_itemPropertyUpdate_cb(self, eventType, eventID, item, **kwargs): ...
    def _CatalogStopWidget__updateAndAdvance(self): ...
    def mousePressEvent(self, event): ...
    def setCatalogItem(self, item): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import QT4GLLayerStack.LayerStack
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
from typing import ClassVar, Set, Tuple

class PixelProbeLayer(QT4GLLayerStack.LayerStack.Layer):
    _SelectBufferSize: ClassVar[int] = ...
    def __init__(self, valuePolicy, *args, **kwargs) -> None: ...
    def defaultProcessEvent(self, event): ...
    def drawGeometry(self): ...
    def getPickedObjects(self, mousePos): ...
    def paintGL(self): ...
    def processDragEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import ConfigurationAPI_cmodule as Configuration
import DrawingModule as DrawingModule
import KatanaResources as KatanaResources
import UI4.App.KeyboardShortcutManager as KeyboardShortcutManager
import NodegraphAPI as NodegraphAPI
import Nodes2DAPI as Nodes2DAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import RenderingAPI as RenderingAPI
import UI4 as UI4
import Utils as Utils
import typing
from PyQt5.QtCore import Qt as Qt
from PyUtilModule.VirtualKatana import KatanaFile as KatanaFile, LayeredMenuAPI as LayeredMenuAPI, Widgets as Widgets
from UI4.KatanaPrefs.KatanaPrefsObject import KatanaPrefs as KatanaPrefs
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from UI4.Tabs.NodeGraphTab.Layers.NodeGraphViewInteractionLayer import RegisterNodeGraphViewKeyboardShortcuts as RegisterNodeGraphViewKeyboardShortcuts
from UI4.Tabs.NodeGraphTab.NodeBreadcrumbsFrame import NodeBreadcrumbsFrame as NodeBreadcrumbsFrame
from UI4.Tabs.NodeGraphTab.NodeFindPopupButton import NodeFindPopupButton as NodeFindPopupButton
from UI4.Tabs.NodeGraphTab.NodeGoUpButton import NodeGoUpButton as NodeGoUpButton
from UI4.Tabs.NodeGraphTab.NodeStateFilterFrame import NodeStateFilterFrame as NodeStateFilterFrame
from UI4.Tabs.NodeGraphTab.NodegraphWidget import NodegraphWidget as NodegraphWidget
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

UNSUPPORTED_MENU_ACTIONS_IN_NETWORK_MATERIAL: dict

class NodegraphPanel(BaseTab):
    _NodegraphPanel__clipboardMimeType: ClassVar[str] = ...
    _NodegraphPanel__kDuplicateShortcutID: ClassVar[str] = ...
    _NodegraphPanel__kDuplicateWithConnectionsShortcutID: ClassVar[str] = ...
    _NodegraphPanel__kToggleInputConnectionVisibleID: ClassVar[str] = ...
    _NodegraphPanel__kUnsupportedMenuActionsInLegacy: ClassVar[dict] = ...
    _NodegraphPanel__maxClipboardSize: ClassVar[int] = ...
    _NodegraphPanel__pixmaps: ClassVar[None] = ...
    currentNodeViewChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, *args) -> None: ...
    @staticmethod
    def _NodegraphPanel__addLayeredMenus(): ...
    def _NodegraphPanel__alignSelected(self): ...
    def _NodegraphPanel__buildMenuBar(self): ...
    def _NodegraphPanel__clone(self): ...
    def _NodegraphPanel__collapseSelected(self): ...
    def _NodegraphPanel__collapseSelectedToStack(self): ...
    def _NodegraphPanel__copy(self, progressDialogTitle: str = ...) -> bool: ...
    def _NodegraphPanel__cut(self): ...
    def _NodegraphPanel__deleteNonContributors(self): ...
    def _NodegraphPanel__disableActions(self, actions: dict, names: Iterable): ...
    def _NodegraphPanel__duplicateSelectedNodes(self): ...
    def _NodegraphPanel__duplicateSelectedNodesWithConnections(self): ...
    def _NodegraphPanel__editSelected(self): ...
    def _NodegraphPanel__enableActions(self, actions: dict): ...
    def _NodegraphPanel__enterSelected(self): ...
    def _NodegraphPanel__esc(self): ...
    def _NodegraphPanel__explodeSelected(self): ...
    def _NodegraphPanel__extractSelected(self): ...
    def _NodegraphPanel__findNodesActionCallback(self): ...
    def _NodegraphPanel__fitBackdropNode(self): ...
    def _NodegraphPanel__getSelectedNodesBehaviours(self): ...
    def _NodegraphPanel__getTotalNumberOfNodes(self, nodes: list[NodegraphAPI.Node]) -> int: ...
    def _NodegraphPanel__goToRoot(self): ...
    def _NodegraphPanel__goUp(self): ...
    def _NodegraphPanel__isolateSelected(self): ...
    def _NodegraphPanel__loadResources(self): ...
    def _NodegraphPanel__lockBackdropNodes(self): ...
    def _NodegraphPanel__mergeSelectedNodes(self): ...
    def _NodegraphPanel__navigationToolbarCallback(self, nodeName: str, isBack: bool): ...
    def _NodegraphPanel__nodeDeleteHandler(self, eventType, eventID, node: NodegraphAPI.Node, *args, **kwargs): ...
    def _NodegraphPanel__node_setLocked_CB(self, args): ...
    def _NodegraphPanel__node_setViewed_CB(self, args): ...
    def _NodegraphPanel__on_colorsMenu_aboutToShow(self): ...
    def _NodegraphPanel__on_editMenu_aboutToShow(self): ...
    def _NodegraphPanel__on_goMenu_aboutToShow(self): ...
    def _NodegraphPanel__on_newMenu_aboutToShow(self): ...
    def _NodegraphPanel__on_viewMenu_aboutToShow(self): ...
    def _NodegraphPanel__paste(self): ...
    def _NodegraphPanel__preferencesCallback(self): ...
    def _NodegraphPanel__processUnfocusedKeyEvent(self, event): ...
    def _NodegraphPanel__setNodeViewHandler(self, _eventType, eventID, node: typing.Optional[NodegraphAPI.Node] = ...): ...
    def _NodegraphPanel__setPreferredViewOptions(self): ...
    def _NodegraphPanel__setRootNodeHandler(self, eventType, eventID, **kwargs): ...
    def _NodegraphPanel__stateLabelHandler(self, _eventType, eventID, text): ...
    def _NodegraphPanel__toggleAutoConnect(self): ...
    def _NodegraphPanel__toggleBypassOfSelected(self): ...
    def _NodegraphPanel__toggleDimNonContributing(self): ...
    def _NodegraphPanel__toggleDimUnconnected(self): ...
    def _NodegraphPanel__toggleErrorsFileIn(self): ...
    def _NodegraphPanel__toggleExpressionLinks(self): ...
    def _NodegraphPanel__toggleLowContrast(self): ...
    def _NodegraphPanel__toggleSelectedNodesInputConnectionVisibility(self): ...
    def _NodegraphPanel__toggleShowPagesConnectedOnly(self): ...
    def _NodegraphPanel__toggleSnapToGrid(self): ...
    def _NodegraphPanel__toggleTeleports(self): ...
    def _NodegraphPanel__toggleThumbnailOfSelected(self): ...
    def _NodegraphPanel__toggleUseColorFromInputPortForConnections(self): ...
    def _NodegraphPanel__toggleViewMasks(self): ...
    def _NodegraphPanel__unlockBackdropNodes(self): ...
    def _NodegraphPanel__updateLockStateMessage(self, node: NodegraphAPI.Node): ...
    def _NodegraphPanel__updateStatusDisplay(self): ...
    def _NodegraphPanel__viewSelected(self): ...
    def aboutToQuit(self): ...
    def closeEvent(self, event: PyQt5.QtGui.QCloseEvent): ...
    def copyPanel(self): ...
    def enableFloatingLayer(self): ...
    def event(self, event): ...
    def floatNodes(self, nodelist): ...
    def frameAll(self): ...
    def frameSelection(self, *args, **kwds): ...
    def getEnteredGroupNode(self) -> NodegraphAPI.GroupNode: ...
    def getMenuBar(self) -> PyQt5.QtWidgets.QMenuBar | None: ...
    def getNodeGraphWidget(self) -> NodegraphWidget: ...
    def getStateOverlayLabel(self): ...
    def goToNode(self, node: NodegraphAPI.Node): ...
    def prepareFloatingLayerWithPasteBounds(self, nodeList): ...
    @classmethod
    def registerKeyboardShortcuts(cls): ...
    def setCurrentNodeView(self, node: NodegraphAPI.Node): ...
    def update(self): ...

class _NodeStateOverlayLabel(PyQt5.QtWidgets.QLabel):
    def __init__(self, parent) -> None: ...

def CopyNodeColorToLinkColor(): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute
from typing import Set, Tuple

def GetRegisteredFunctionNames(omitInternal: bool = ...) -> list: ...
def Run(name: str, args: PyFnAttribute.Attribute) -> PyFnAttribute.Attribute: ...



from typing import Any
from Callbacks.Callbacks import Callbacks as Callbacks
import AssetAPI as AssetAPI, AssetBrowser as AssetBrowser, CacheManager as CacheManager, CatalogAPI as CatalogAPI, DrawingModule as DrawingModule, GeoAPI as GeoAPI, KatanaResources as KatanaResources, LookFileBakeAPI as LookFileBakeAPI, MachineInfo as MachineInfo, MediaCacheHandler as MediaCacheHandler, Naming as Naming, NodeGraphView as NodeGraphView, NodegraphAPI as NodegraphAPI, Nodes2DAPI as Nodes2DAPI, Nodes3DAPI as Nodes3DAPI, PluginSystemAPI as PluginSystemAPI, QT4Browser as QT4Browser, QT4Color as QT4Color, QT4FormWidgets as QT4FormWidgets, QT4GLLayerStack as QT4GLLayerStack, QT4Panels as QT4Panels, QT4Widgets as QT4Widgets, QTFCurve as QTFCurve, Qt as Qt, RenderingAPI as RenderingAPI, RerenderEventMapper as RerenderEventMapper, ResourceFiles as ResourceFiles, Utils as Utils, ViewerAPI as ViewerAPI, WorkQueue as WorkQueue

import PyFnAttribute as PyFnAttribute
import PyFnGeolibServices as PyFnGeolibServices
import PyFnGeolibProducers as PyFnGeolibProducers
import PyFnGeolib as PyFnGeolib
import ConfigurationAPI_cmodule as ConfigurationAPI_cmodule
import PyResolutionTableFn as PyResolutionTableFn
import Nodes3DAPI.ScenegraphManager as ScenegraphManager

import _PyOpenColorIO as _OCIO
# assign to variable to re-export
OCIO = _OCIO

FnGeolib = PyFnGeolib
FnAttribute = PyFnAttribute
FnGeolibServices = PyFnGeolibServices
FnGeolibProducers = PyFnGeolibProducers
Configuration = ConfigurationAPI_cmodule
ResolutionTable = PyResolutionTableFn
from PyUtilModule import Initialize as Initialize, AttrDump as AttrDump, ChildProcess as ChildProcess, ColorPaletteManager as ColorPaletteManager, Decorators as Decorators, FarmAPI as FarmAPI, Hints as Hints, IRFs as IRFs, KatanaFile as KatanaFile, LiveRenderAPI as LiveRenderAPI, NodeDebugOutput as NodeDebugOutput, NonUIPluginManager as NonUIPluginManager, OpDocumentationGenerator as OpDocumentationGenerator, ProjectSnapshot as ProjectSnapshot, RegisterToCamera as RegisterToCamera, RenderManager as RenderManager, RenderingCommon as RenderingCommon, ScenegraphBookmarkManager as ScenegraphBookmarkManager, ScenegraphUtils as ScenegraphUtils, Shelves as Shelves, SuperToolPlugins as SuperToolPlugins, UserNodes as UserNodes, WorkingSet as WorkingSet, WorkingSetClient as WorkingSetClient, WorkingSetManager as WorkingSetManager

Plugins: Any



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import PyUtilModule as PyUtilModule
import PyXmlIO as PyXmlIO
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.Widgets.SortablePanel
import Naming as UniqueName
import Utils as Utils
from PyUtilModule.Decorators import undogroup as undogroup
from UI4.FormMaster.Editors.ConditionalHints import ConditionalHintEditorDialog as ConditionalHintEditorDialog, GetConditionalNamesFromHintDict as GetConditionalNamesFromHintDict
from UI4.FormMaster.Editors.UserParametersDialogs import ChangeWidgetType as ChangeWidgetType, GetWidgetDisplayName as GetWidgetDisplayName, GetWidgetListForType as GetWidgetListForType, HelpTextDialog as HelpTextDialog, ParameterRenameDialog as ParameterRenameDialog, ShowWidgetOptionsDialog as ShowWidgetOptionsDialog
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class ChildParameterPanel(UI4.Widgets.SortablePanel.ParameterSortablePanel):
    def __init__(self, parent, name, policy, widgetFactory, panelArgs: Incomplete | None = ...) -> None: ...
    def _ChildParameterPanel__buildWrenchMenu(self): ...
    def _ChildParameterPanel__childWidgetVisChange(self, state, w): ...
    def _ChildParameterPanel__editConditionalLock(self): ...
    def _ChildParameterPanel__editConditionalState(self, hintType, windowTitle): ...
    def _ChildParameterPanel__editConditionalVisibility(self): ...
    def _ChildParameterPanel__editHelpTextCallback(self): ...
    def _ChildParameterPanel__editWidgetOptions(self): ...
    def _ChildParameterPanel__getHints(self): ...
    def _ChildParameterPanel__renameParameter(self): ...
    def _ChildParameterPanel__widgetTypeTriggered(self, action): ...
    def getValuePolicy(self): ...
    def getWidget(self): ...

class UndoableAction:
    def __init__(self, name, callback) -> None: ...
    def __call__(self): ...

class UserParametersEditor(UI4.Widgets.SortablePanel.ParameterSortablePanelFormWidget):
    NullWidgetHintString: ClassVar[str] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _UserParametersEditor__addButtonParameter(self): ...
    def _UserParametersEditor__addCapsuleParameter(self): ...
    def _UserParametersEditor__addColorGradientParameter(self): ...
    def _UserParametersEditor__addColorParameterRGB(self): ...
    def _UserParametersEditor__addColorParameterRGBA(self): ...
    def _UserParametersEditor__addColorRampParameter(self): ...
    def _UserParametersEditor__addFloatRampParameter(self): ...
    def _UserParametersEditor__addFloatVectorParameter(self): ...
    def _UserParametersEditor__addGroupParameter(self): ...
    def _UserParametersEditor__addNodeDropProxyParameter(self): ...
    def _UserParametersEditor__addNumberArrayParameter(self): ...
    def _UserParametersEditor__addNumberParameter(self): ...
    def _UserParametersEditor__addSeparator(self): ...
    def _UserParametersEditor__addStringArrayParameter(self): ...
    def _UserParametersEditor__addStringParameter(self, hints: Incomplete | None = ..., name: Incomplete | None = ...): ...
    def _UserParametersEditor__addTeleParameter(self): ...
    def _UserParametersEditor__addToolbarParameter(self): ...
    def _UserParametersEditor__buildArrayStructure(self, typeName, size, tupleSize, default, hints: Incomplete | None = ...): ...
    def _UserParametersEditor__getDragSourceAndIndex(self, ev): ...
    def _UserParametersEditor__getDropParameter(self, mimeData): ...
    def _UserParametersEditor__getParam(self): ...
    def _getPanelForPolicy(self, vp): ...
    def addButtonCheckDragEvent(self, event): ...
    def addButtonDropEvent(self, event): ...
    def buildAddMenu(self, menu): ...
    def dragEnterEvent(self, ev): ...
    def dragMoveEvent(self, ev): ...
    def dropEvent(self, ev): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import Nodes3DAPI.ScenegraphManager as ScenegraphManager
import PyUtilModule.ScenegraphUtils as ScenegraphUtils
import Utils as Utils
from _typeshed import Incomplete
from typing import Set, Tuple

def GetScenegraphMaskEnabled(): ...
def GetScenegraphMaskLocationsAndRoot(cameraPath: str, selectedLocations: Incomplete | None = ...): ...
def GetScengraphMaskLocations() -> list[str]: ...
def GetVisibilityFollowsWorkingSet(): ...
def SetScenegraphMaskEnabled(scenegraphMaskEnabled): ...
def SetVisibilityFollowsWorkingSet(enabled): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
from QT4FormWidgets.FormWidget import FormWidget
from typing import Set, Tuple

class ShadingNodeConnectedParameterFormWidget(FormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _ShadingNodeConnectedParameterFormWidget__jumpButtonClick(self): ...
    def _ShadingNodeConnectedParameterFormWidget__updateLabel(self): ...
    def _buildControlWidget(self, layout): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import CatalogAPI as CatalogAPI
import CatalogAPI.CatalogItem
import ConfigurationAPI_cmodule as Configuration
import UI4.Util.IconManager as IconManager
import UI4.Tabs.Catalog.ImageImportDialog as ImageImportDialog
import UI4.KatanaPrefs as KatanaPrefs
import KatanaResources as KatanaResources
import NodegraphAPI as NodegraphAPI
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtGui
import PyQt5.QtWidgets
import QT4Widgets.SortableTreeWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.Widgets.CatalogThumbnailWidget
from CatalogAPI.CatalogItem import CatalogItem
from CatalogWidget import CatalogWidget
from PyUtilModule.VirtualKatana import RenderManager as RenderManager
from QT4Widgets.SortableTreeWidget import SortableTreeWidgetItem as SortableTreeWidgetItem, SortableTreeWidgetItemDelegate as SortableTreeWidgetItemDelegate
from UI4.KatanaPrefs.KatanaPrefsObject import Prefs as Prefs
from UI4.Widgets.CatalogThumbnailWidget import CatalogItemThumbnailMixin as CatalogItemThumbnailMixin
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

BOUNDS_COLUMN: int
COMMENT_COLUMN: int
ELAPSED_COLUMN: int
FRAME_COLUMN: int
GSVS_COLUMN: int
ID_COLUMN: int
IRFS_COLUMN: int
ISVIEWED_COLUMN: int
LAYERVIEWS_COLUMN: int
LOCKED_COLUMN: int
NODENAME_COLUMN: int
NUM_COLUMNS: int
PIN_COLUMN: int
SAVED_COLUMN: int
SLOT_COLUMN: int
SPACER_COLUMN: int
START_COLUMN: int
THUMBNAIL_COLUMN: int

class CatalogSlotParentItem(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItem):
    def __init__(self, slot, *args) -> None: ...
    def getCatalogItem(self): ...
    def getSlot(self): ...
    def paintDelegate(self, baseClass, delegate, painter, option, index): ...
    def updateTextColor(self): ...

class CatalogWidgetItem(UI4.Widgets.CatalogThumbnailWidget.CatalogItemThumbnailMixin, QT4Widgets.SortableTreeWidget.SortableTreeWidgetItem):
    _kMaxThumbnailHeight: ClassVar[int] = ...
    _kUnpinnedColor: ClassVar[PyQt5.QtGui.QColor] = ...
    def __init__(self, catalogItem, *args) -> None: ...
    def _CatalogWidgetItem__adoptFrameTime(self): ...
    def _CatalogWidgetItem__adoptROI(self): ...
    def _CatalogWidgetItem__canFindInNodeGraph(self) -> bool: ...
    def _CatalogWidgetItem__duplicateItem(self): ...
    def _CatalogWidgetItem__findInNodegraph(self): ...
    def _CatalogWidgetItem__getIndividualGSVLabeL(self, column: int) -> _GSVLabel: ...
    def _CatalogWidgetItem__importImageSequence(self, location, view): ...
    def _CatalogWidgetItem__regenerateThumbnail(self): ...
    @staticmethod
    def _CatalogWidgetItem__selectPrimaryCatalogItem(clientKey: int, catalogItem: CatalogItem): ...
    @staticmethod
    def _CatalogWidgetItem__updateClientPinned(clientKey: int, catalogItem: CatalogItem): ...
    def _onCatalogItemChanged(self): ...
    def buildContextMenu(self, parent: CatalogWidget, column: int) -> PyQt5.QtWidgets.QWidget: ...
    def handleMousePressEvent(self, button, col): ...
    def paintDelegate(self, baseClass, delegate, painter, option, index): ...
    def refreshEverything(self): ...
    def refreshGSVsAndIRFs(self): ...
    def refreshProperties(self): ...
    def refreshUserComment(self): ...
    def updateThumbnailPixmap(self, width: int) -> bool: ...

class CatalogWidgetItemDelegate(QT4Widgets.SortableTreeWidget.SortableTreeWidgetItemDelegate):
    _CatalogWidgetItemDelegate__minHeight: ClassVar[int] = ...
    def createEditor(self, parent, option, index): ...
    def paint(self, painter, option, index): ...
    def setModelData(self, editor, model, index): ...
    def sizeHint(self, option, index): ...

class _FrameLabel(_PinnableLabel):
    def _getLabelCheckedStateAndVisibility(self): ...
    def _on_checkBox_stateChanged(self, state): ...

class _GSVLabel(_PinnableLabel):
    def __init__(self) -> None: ...
    def _getLabelCheckedStateAndVisibility(self): ...
    def _on_checkBox_stateChanged(self, state): ...
    def setName(self, name: str): ...

class _GSVsLabel(PyQt5.QtWidgets.QLabel):
    class _GSV(tuple):
        _field_defaults: ClassVar[dict] = ...
        _fields: ClassVar[tuple] = ...
        _fields_defaults: ClassVar[dict] = ...
        def __init__(self, _cls, key, value, isPinned) -> None: ...
        def _asdict(self): ...
        @classmethod
        def _make(cls, iterable): ...
        def _replace(self, _self, **kwds): ...
        def __getnewargs__(self): ...
        @property
        def isPinned(self): ...
        @property
        def key(self): ...
        @property
        def value(self): ...
    _kUnpinnedGSVColour: ClassVar[str] = ...
    def __init__(self) -> None: ...
    def _GSVsLabel__updateText(self): ...
    def resizeEvent(self, event: PyQt5.QtGui.QResizeEvent): ...
    def updateGSVs(self, catalogItem: CatalogItem): ...

class _Icon(PyQt5.QtWidgets.QLabel):
    kAlignment: ClassVar[PyQt5.QtCore.Qt.Alignment] = ...
    kTopBottomMargin: ClassVar[int] = ...
    def __init__(self) -> None: ...
    def updatePixmap(self, pixmap: PyQt5.QtGui.QPixmap | None): ...

class _PinColumnCheckBox(PyQt5.QtWidgets.QWidget):
    def __init__(self) -> None: ...
    def _PinColumnCheckBox__on_checkBox_stateChanged(self, state: int): ...
    def updateItem(self, catalogItem: CatalogAPI.CatalogItem.CatalogItem | None): ...

class _PinnableLabel(PyQt5.QtWidgets.QWidget):
    _kHighlightColor: ClassVar[PyQt5.QtGui.QColor] = ...
    def __init__(self) -> None: ...
    def _getLabelCheckedStateAndVisibility(self) -> Tuple[str, bool, bool]: ...
    def _on_checkBox_stateChanged(self, state: int): ...
    def getText(self) -> str: ...
    def updateItem(self, catalogItem: CatalogItem): ...
    def updateTextColor(self, defaultTextColor: Incomplete | None = ...): ...

class _PinnedVariablesMenu(PyQt5.QtWidgets.QDialog):
    def __init__(self, parent: PyQt5.QtWidgets.QWidget, catalogItem: CatalogItem) -> None: ...
    def _PinnedVariablesMenu__buildHeaderWidget(self) -> PyQt5.QtWidgets.QWidget: ...
    def _PinnedVariablesMenu__buildScrollAreaWidget(self) -> PyQt5.QtWidgets.QWidget: ...
    def _PinnedVariablesMenu__on_button_clicked(self): ...
    def _PinnedVariablesMenu__on_frameCheckBox_stateChanged(self, state: int): ...
    def _PinnedVariablesMenu__on_varCheckBox_stateChanged(self, state: int): ...
    def _PinnedVariablesMenu__updateOnAndOffButtons(self): ...
    def exec_(self, pos: PyQt5.QtCore.QPoint) -> int: ...

class _TickIcon(_Icon):
    def __init__(self) -> None: ...

def GetColumnID(columnKeyName: str) -> int | None: ...
def GetColumnKeyName(columnID: int) -> str: ...
def GetColumnName(columnID): ...
def GetDefaultColumnWidth(columnID): ...
def SetDefaultColumnWidth(columnID, size): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.InputWidgets as InputWidgets
import QT4FormWidgets.PaintingUtils as PaintingUtils
import PyQt5.QtCore
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.BaseValueFormWidget import BaseValueFormWidget as BaseValueFormWidget
from QT4FormWidgets.FormWidget import AlignChildLabelWidths as AlignChildLabelWidths, AlignLeftControlWidths as AlignLeftControlWidths, FormWidget as FormWidget, ScrubbingStates as ScrubbingStates
from QT4FormWidgets.MultiStateBadge import MultiStateBadge as MultiStateBadge, ToggleStateBadge as ToggleStateBadge, ToggleValuePolicyState as ToggleValuePolicyState
from typing import ClassVar, Set, Tuple

class TextFormWidget(BaseValueFormWidget):
    backtabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabPressed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def _TextFormWidget__indentText(self): ...
    def _TextFormWidget__unindentText(self): ...
    def _buildControlWidget(self, layout): ...
    def _checkControlWidget(self): ...
    def _controlTextChanged(self): ...
    def _getControlWidget(self): ...
    def _lockChanged(self, state): ...
    def _updateControlWidget(self): ...
    def eventFilter(self, watched, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtGui
import QT4Widgets as QT4Widgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from _typeshed import Incomplete
from typing import Set, Tuple

MouseButtonClick: int

class ClickFilter:
    def __init__(self) -> None: ...
    def process(self, event): ...

class EventProcessor:
    def __init__(self) -> None: ...
    def finish(self, cancelled: bool = ...): ...
    def isFinished(self): ...
    def processEvent(self, event): ...

class EventProcessorHandler:
    def __init__(self) -> None: ...
    def _EventProcessorHandler__runEventProcessor(self, event): ...
    def _processEvent(self, event): ...
    def _processEventUnconditional(self, event): ...
    def getEventProcessor(self): ...
    def processEvent(self, event): ...
    def setEventProcessor(self, eventProcessor, eventToProcess: Incomplete | None = ...): ...

class LayerWorldDragEventProcessor(EventProcessor):
    def __init__(self, layer, trackModifiers: PyQt5.QtCore.Qt.KeyboardModifier = ..., trackModifierKeys: tuple = ...) -> None: ...
    def _getLayer(self): ...
    def _getModifiers(self): ...
    def _getWorldEnd(self): ...
    def _getWorldStart(self): ...
    def _update(self, worldStart, worldEnd, modifiers, initial: bool = ..., endChanged: bool = ..., modifiersChanged: bool = ..., final: bool = ...): ...
    def processEvent(self, event): ...

class MouseClickEvent(PyQt5.QtGui.QMouseEvent):
    def __init__(self, releaseEvent) -> None: ...
    def type(self): ...
    def __getattr__(self, attr): ...
    def __hasattr__(self, attr): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from QT4Color.ColorPolicy import CreateColorPolicy as CreateColorPolicy, DoesColorPolicyEnableFilmlook as DoesColorPolicyEnableFilmlook, DoesColorPolicyEnableNoFilmlookColorSpace as DoesColorPolicyEnableNoFilmlookColorSpace, DoesColorPolicyHaveAlpha as DoesColorPolicyHaveAlpha, DoesColorPolicyRestrictComponents as DoesColorPolicyRestrictComponents, GetColorPolicyChildren as GetColorPolicyChildren, GetColorPolicyRGBA as GetColorPolicyRGBA, GetDefaultColorComponentTab as GetDefaultColorComponentTab, SetColorPolicyEnableFilmlook as SetColorPolicyEnableFilmlook, SetColorPolicyEnableFilmlookDefault as SetColorPolicyEnableFilmlookDefault, SetColorPolicyEnableNoFilmlookColorSpaceDefault as SetColorPolicyEnableNoFilmlookColorSpaceDefault, SetColorPolicyRGBA as SetColorPolicyRGBA, SetColorPolicyRestrictComponents as SetColorPolicyRestrictComponents, SetColorPolicyRestrictComponentsDefault as SetColorPolicyRestrictComponentsDefault
from QT4Color.Gradient1D import LinearGradientWidget as LinearGradientWidget
from QT4FormWidgets.NumberFormWidget import NumberFormWidget
from typing import Set, Tuple

class ColorComponentFormWidget(NumberFormWidget):
    def __init__(self, colorComponent, parent, colorPolicy, widgetFactory) -> None: ...
    def _buildControlWidget(self, layout): ...
    def doSliderMoved(self, change): ...
    def doSliderPressed(self): ...
    def doSliderReleased(self): ...
    def getMode(self): ...
    def getPopdownWidget(self): ...
    def resetChildValuePolicy(self): ...
    def setLocked(self, state, checkLockOps: bool = ...): ...
    def toggleColorClamping(self): ...
    def toggleFilmlookVisualization(self): ...

def BuildColorComponentQT4FormWidgets(colorPolicy, parent, includeHSL: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Tabs.DopeSheet.DopeSheetTree as DopeSheetTree
import UI4.Tabs.DopeSheet.KeyLayerStack as KeyLayerStack
import NodegraphAPI as NodegraphAPI
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import UI4.FormMaster.ParameterCurveEditSet
import Utils as Utils
from UI4.FormMaster.ParameterCurveEditSet import ParameterCurveEditWatcher as ParameterCurveEditWatcher
from UI4.Tabs.BaseTab import BaseTab as BaseTab
from typing import Set, Tuple

class DopeSheetPanel(BaseTab, UI4.FormMaster.ParameterCurveEditSet.ParameterCurveEditWatcher):
    def __init__(self, parent) -> None: ...
    def _DopeSheetPanel__buildTreeItemContextMenu(self, menu): ...
    def _DopeSheetPanel__checkCurvable(self, vp): ...
    def _DopeSheetPanel__expandOrCollapseCB(self, item): ...
    def _DopeSheetPanel__extractParams(self, event): ...
    def _DopeSheetPanel__getEntry(self, paramFullName, create: bool = ...): ...
    def _DopeSheetPanel__getParamFromName(self, paramFullName, excludeExpressions: bool = ...): ...
    def _DopeSheetPanel__getParamKeys(self, paramFullName): ...
    def _DopeSheetPanel__getParamNamesForItems(self, items): ...
    def _DopeSheetPanel__getParamNamesFromSelection(self): ...
    def _DopeSheetPanel__getParamsFromSelection(self): ...
    def _DopeSheetPanel__makeSelectedConstant(self): ...
    def _DopeSheetPanel__selectKeysForSelectedItems(self): ...
    def _DopeSheetPanel__setDisplayUpdatesEnabled(self, enableRaw, updateOnEnable: bool = ...): ...
    def _DopeSheetPanel__unCurvafySelectedItems(self): ...
    def _DopeSheetPanel__updateDisplay(self, *args): ...
    def _DopeSheetPanel__updateScroll(self, *args): ...
    def _DopeSheetPanel__viewCurves(self, vp): ...
    def _initializeSet(self, curveEditSetCopy): ...
    def _keysChanged(self, paramFullName): ...
    def _nameChanged(self, oldParamFullName, newParamFullName, newParamLocalName): ...
    def _nodeNameChanged(self, oldNodeName, newNodeName): ...
    def _showKeys(self, paramFullName, show): ...
    def dragEnterEvent(self, event): ...
    def dropEvent(self, event): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import Set, Tuple

class FixableBoxLayout(PyQt5.QtWidgets.QBoxLayout):
    def __init__(self, orient: PyQt5.QtWidgets.QBoxLayout.Direction = ..., parent: Incomplete | None = ...) -> None: ...
    def setFixedWidth(self, fixedWidth): ...
    def sizeHint(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import Utils as Utils
from typing import Set, Tuple

class ParameterCurveEditWatcher:
    def __init__(self) -> None: ...
    def _ParameterCurveEditWatcher__node_setEdited_callback(self, args): ...
    def _ParameterCurveEditWatcher__node_setName_callback(self, args): ...
    def _ParameterCurveEditWatcher__parameter_finalizeValue_callback(self, args): ...
    def _ParameterCurveEditWatcher__parameter_setName_callback(self, args): ...
    def _ParameterCurveEditWatcher__parameter_showKeys_callback(self, args): ...
    def _initializeSet(self, curveEditSetCopy): ...
    def _isActive(self, paramFullName): ...
    def _keysActiveChanged(self, paramFullName, active): ...
    def _keysChanged(self, paramFullName): ...
    def _nameChanged(self, oldParamFullName, newParamFullName, newParamLocalName): ...
    def _nodeNameChanged(self, oldNodeName, newNodeName): ...
    def _showKeys(self, paramFullName, show): ...

def ClearParameterCurveEditSet(): ...
def GetParameterCurveEdited(fullParamName): ...
def SetParameterCurveEdited(fullParamName, setEdit): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import ProjectSettings as ProjectSettings
from UI4.Tabs.ParametersTab.ParameterPanel import ParameterPanel as ParameterPanel, TearoffParameterTab as TearoffParameterTab
from UI4.Tabs.ParametersTab.ProjectSettings import ProjectSettingsTab as ProjectSettingsTab
from typing import Set, Tuple

PluginRegistry: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI
from _typeshed import Incomplete
from typing import Set, Tuple

def GetModifiedFrameTime(node: NodegraphAPI.Node, frameTime): ...
def GetTimingParameterAttrsForNodeTypeBuilder(): ...
def GetTimingParameterHints(attrName: Incomplete | None = ...): ...
def GetTimingParameterXML(): ...
def HasTimingParameter(node: NodegraphAPI.Node): ...
def SetTimingParametersExpressionsForNodeTypeBuilder(node: NodegraphAPI.Node): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class AbstractFileTableModel(PyQt5.QtCore.QAbstractTableModel):
    _headers: ClassVar[list] = ...
    layoutAboutToBeChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    layoutChanged: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def columnCount(self, parent): ...
    def data(self, index, role): ...
    def headerData(self, section, orientation, role): ...
    def rowCount(self, parent): ...
    def sort(self, column, order): ...

class FileInfoDisplay(PyQt5.QtWidgets.QFrame):
    def __init__(self, *args) -> None: ...
    def setFile(self, file): ...

class FileInfoItem:
    DIRECTORY: ClassVar[int] = ...
    FILE: ClassVar[int] = ...
    LINK: ClassVar[int] = ...
    SEQUENCE: ClassVar[int] = ...
    _DIRECTORY_ICON_DATA: ClassVar[bytes] = ...
    _FILE_ICON_DATA: ClassVar[bytes] = ...
    _SEQUENCE_ICON_DATA: ClassVar[bytes] = ...
    _UID_CACHE: ClassVar[dict] = ...
    _iconmap: ClassVar[dict] = ...
    def __init__(self, name, *args) -> None: ...
    def icon(self): ...
    def isVisible(self): ...
    def mtime(self): ...
    def mtimeString(self): ...
    def name(self): ...
    def nameKey(self): ...
    def owner(self): ...
    def setVisible(self, flag): ...
    def text(self): ...
    def type(self): ...

class FileTableView(PyQt5.QtWidgets.QTableView):
    def __init__(self, parent: Incomplete | None = ...) -> None: ...
    def _FileTableView__restoreSelectedText(self): ...
    def _FileTableView__saveSelectedText(self): ...
    def _modelReset(self): ...
    def _resizeColumns(self): ...
    def getSelectedText(self): ...
    def setModel(self, model): ...
    def setSelectedText(self, text): ...

def IsDir(path): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from typing import Set, Tuple

def ClampRGBA(rgba): ...
def ConvertColorToUnits(units, rgbColor): ...
def ConvertUnitsToColor(units, unitsColor): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import DrawingModule as DrawingModule
import QT4FormWidgets.InputWidgets as InputWidgets
import UI4.FormMaster.Editors.NodeGroup as NodeGroup
import NodegraphAPI as NodegraphAPI
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtWidgets as QtWidgets
import UI4.Widgets.SortablePanel as SortablePanel
import UI4 as UI4
import UI4.FormMaster.Editors.NodeGroup
import UI4.Widgets.SortablePanel
import Utils as Utils
from typing import Set, Tuple

class InputPanel(UI4.Widgets.SortablePanel.SortablePanelBase):
    def __init__(self, parent, name) -> None: ...
    def _InputPanel__valueChangedCallback(self): ...
    def getPortName(self): ...
    def setPortName(self, name): ...

class TeleportEditor(UI4.FormMaster.Editors.NodeGroup.NodeGroupFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _TeleportEditor__clicked(self): ...

class TeleportInputEditor(UI4.Widgets.SortablePanel.SortablePanelFormWidget):
    def __init__(self, parent, valuePolicy, widgetFactory) -> None: ...
    def _TeleportInputEditor__getEventTarget(self): ...
    def _TeleportInputEditor__getNode(self): ...
    def _TeleportInputEditor__idle_callback(self, *args, **kwargs): ...
    def _TeleportInputEditor__node_addOrRemoveOutputPort_cb(self, *args, **kwargs): ...
    def _TeleportInputEditor__node_renameOutputPort_cb(self, *args, **kwargs): ...
    def addInput(self): ...
    def buildAddMenu(self, menu): ...
    def deleteInput(self, index): ...
    def deletePanel(self, index): ...
    def panelReordered(self, oldPos, newPos): ...
    def panelValueChanged(self, index): ...
    def renameInput(self, index, newName): ...
    def valueChanged(self, valuePolicy, index, final): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import PackageSuperToolAPI.Packages
import PyFnAttribute
import PyXmlIO
import QT4FormWidgets as QT4FormWidgets
import QT4FormWidgets.ValuePolicy
import Utils as Utils
import typing
from PyUtilModule.VirtualKatana import FormMaster as FormMaster
from _typeshed import Incomplete
from typing import Any, Callable, Set, Tuple

class DeferredNodeBypassPolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, parent: QT4FormWidgets.AbstractValuePolicy, nodeType: str, policyName: str, checkboxText: str, policyTitle: str, package: PackageSuperToolAPI.Packages.Package, parameterNames: list[str], parameterPolicyConstructor: Callable = ..., newPolicyCreatedCallback: typing.Optional[typing.Callable] = ...) -> None: ...
    def _DeferredNodeBypassPolicy__on_node_create(self, eventType: str | None, eventID: object, node: NodegraphAPI.Node, nodeType: str, nodeName: str): ...
    def _DeferredNodeBypassPolicy__on_node_delete(self, eventType: str | None, eventID: object, node: NodegraphAPI.Node, oldName: str): ...
    def _DeferredNodeBypassPolicy__on_node_setBypassed(self, eventType: str | None, eventID: object, node: NodegraphAPI.Node, **kwargs): ...
    def _DeferredNodeBypassPolicy__setNode(self, node: NodegraphAPI.Node | None): ...
    def _DeferredNodeBypassPolicy__setValue(self, value: bool, final: bool = ...): ...
    def _DeferredNodeBypassPolicy__updateParameterPolicy(self): ...
    def addChildPolicy(self, policy: QT4FormWidgets.AbstractValuePolicy): ...
    def getChildByName(self, name) -> QT4FormWidgets.AbstractValuePolicy | None: ...
    def getChildren(self) -> list[QT4FormWidgets.AbstractValuePolicy]: ...
    def getName(self) -> str: ...
    def getNumChildren(self) -> int: ...
    def getType(self) -> str: ...
    def getValue(self) -> float: ...
    def getWidgetHints(self) -> dict[str, Any]: ...
    def isLocked(self) -> bool: ...
    def setValue(self, value: float, final: bool = ...) -> bool: ...

class DeferredParameterCreatePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, parent: QT4FormWidgets.AbstractValuePolicy, node: NodegraphAPI.Node, checkboxText: str, package: PackageSuperToolAPI.Packages.Package, getterCallback: typing.Callable, setterCallback: typing.Callable, exposedParameterName: str, monitoredParameterNames: Incomplete | None = ...) -> None: ...
    def _DeferredParameterCreatePolicy__createParameterPolicy(self): ...
    def _DeferredParameterCreatePolicy__on_parameter_createChild(self, eventType: str | None, eventID: object, param: NodegraphAPI.Parameter, paramName: str, node: NodegraphAPI.Node, childParam: NodegraphAPI.Parameter, element: PyXmlIO.Element, index: int): ...
    def _DeferredParameterCreatePolicy__on_parameter_deleteChild(self, eventType: str | None, eventID: object, param: NodegraphAPI.Parameter, paramName: str, node: NodegraphAPI.Node, childParam: NodegraphAPI.Parameter, element: PyXmlIO.Element, childName, index: int): ...
    def _DeferredParameterCreatePolicy__updateValue(self, value: Incomplete | None = ..., final: bool = ...): ...
    def addChildPolicy(self, policy: QT4FormWidgets.AbstractValuePolicy): ...
    def getChildByName(self, name) -> QT4FormWidgets.AbstractValuePolicy | None: ...
    def getChildren(self) -> list[QT4FormWidgets.AbstractValuePolicy]: ...
    def getName(self) -> str: ...
    def getNumChildren(self) -> int: ...
    def getType(self) -> str: ...
    def getValue(self) -> float: ...
    def getWidgetHints(self) -> dict[str, Any]: ...
    def isLocked(self) -> bool: ...
    def removeChildPolicy(self, policy: QT4FormWidgets.AbstractValuePolicy): ...
    def setValue(self, value: float, final: bool = ...) -> bool: ...

class ParentProxyValuePolicy(QT4FormWidgets.ValuePolicy.AbstractValuePolicy):
    def __init__(self, parent: QT4FormWidgets.AbstractValuePolicy, name: str) -> None: ...
    def getName(self) -> str: ...
    def getType(self) -> str: ...
    def getValue(self) -> Any: ...
    def getWidgetHints(self) -> dict[str, Any]: ...
    def isLocked(self) -> bool: ...
    def setValue(self, value: float, final: bool = ...) -> bool: ...

class PotentialParameterProxyPolicy(QT4FormWidgets.ValuePolicy.ValuePolicyProxy):
    def __init__(self, parent: ValuePolicy, attrName: str) -> None: ...
    def _PotentialParameterProxyPolicy__getMetadataDict(self, locationAttributes: PyFnAttribute.GroupAttribute) -> dict: ...
    def getAttrName(self) -> str: ...
    def getName(self) -> str: ...
    def getParent(self) -> ValuePolicy: ...
    def switchToAttributePolicy(self, locationAttributes: PyFnAttribute.GroupAttribute): ...
    def switchToParameterPolicy(self, parameter: NodegraphAPI.Node3D): ...
    def updateAttribute(self, locationAttributes: PyFnAttribute.GroupAttribute): ...

def DefaultParameterPolicyConstructor(package: PackageSuperToolAPI.Packages.Package, parentPolicy: QT4FormWidgets.ParameterPolicy, name: str, parameter: NodegraphAPI.Parameter) -> QT4FormWidgets.ParameterPolicy: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import UI4.Util.IconManager as IconManager
import KatanaResources as KatanaResources
import UI4.NodeMaster as NodeMaster
import NodegraphAPI as NodegraphAPI
import UI4.FormMaster.Editors.PolicyFindPopup as PolicyFindPopup
import UI4.KatanaPrefs.PrefNames as PrefNames
import PyQt5.QtCore
import PyQt5.QtGui
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
import PyUtilModule.Shelves as Shelves
import PyUtilModule.SuperToolPlugins as SuperToolPlugins
import UI4.FormMaster.Editors.HideTitleGroup
import Utils as Utils
import UI4.Widgets as Widgets
from UI4.FormMaster.Editors.HideTitleGroup import HideTitleGroupFormWidget as HideTitleGroupFormWidget
from UI4.FormMaster.KatanaFactory import ParameterWidgetFactory as ParameterWidgetFactory
from UI4.Widgets.PopupButton import PopupButton
from Utils.Decorators import deprecated as deprecated
from typing import ClassVar, Set, Tuple

g_nodeSpecificShelves: None

class CommentButton(PopupButton):
    def __init__(self, parent) -> None: ...
    def _CommentButton__aboutToShow(self): ...
    def _CommentButton__commentEditAreaReturnPressed(self): ...

class NodeGroupFormWidget(UI4.FormMaster.Editors.HideTitleGroup.HideTitleGroupFormWidget):
    kDeprecatedColor: ClassVar[PyQt5.QtGui.QColor] = ...
    popdownStateChange: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    tabClosed: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, parent, policy, factory) -> None: ...
    def _NodeGroupFormWidget__doNodeSetComment(self, args): ...
    def _NodeGroupFormWidget__doNodeSetLocked(self, args): ...
    def _NodeGroupFormWidget__doNodeSetName(self, args): ...
    def _NodeGroupFormWidget__nameEditClearButton_CB(self): ...
    def _NodeGroupFormWidget__on_nodeButton_clicked(self): ...
    def _NodeGroupFormWidget__setAutoRenameAllowed_CB(self, eventType, eventID, node: NodegraphAPI.Node, **kwargs): ...
    def _NodeGroupFormWidget__updateNameEditClearVisibility(self): ...
    def _buildControlWidget(self, layout): ...
    def _buildFindWidget(self, layout): ...
    def _buildHelpButton(self, policy): ...
    def _buildLabel(self, labelText, pos: int = ...): ...
    def _buildLock(self, layout): ...
    def _buildWrench(self, policy): ...
    def _findChildWidget(self, path): ...
    def _freeze(self): ...
    def _removeWrench(self, wrench): ...
    def _thaw(self): ...
    def closeEvent(self, event): ...
    def contextMenuEvent(self, event): ...
    def getNameEdit(self): ...
    def getShortcutsContextName(self): ...
    def showFindPopup(self): ...

class SuperToolFormWidget(NodeGroupFormWidget):
    def __init__(self, parent, policy, factory) -> None: ...
    def _SuperToolFormWidget__handleParameterPolicyEvent(self, valuePolicyEvent): ...
    def _buildFindWidget(self, layout): ...
    def _popdownCreated(self, popdown): ...
    def getTopologyDifferences(self): ...
    def setLocked(self, locked: bool): ...

def _GetNodeSpecificShelves(forceReload: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnAttribute
import Utils as Utils
from typing import Set, Tuple

def AttrToHints(attr: PyFnAttribute.Attribute) -> Tuple[int, float, str, list, dict | None]: ...
def AttrToObject(attr: PyFnAttribute.Attribute) -> Tuple[int, float, str, list, dict | None]: ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtCore as QtCore
from UI4.App.KeyboardShortcutManager.KeyboardShortcutItem import KeyboardShortcutItem as KeyboardShortcutItem
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class KeyboardShortcutModel(PyQt5.QtCore.QAbstractItemModel):
    _KeyboardShortcutModel__headers: ClassVar[tuple] = ...
    def __init__(self, data: dict, parent: Incomplete | None = ...) -> None: ...
    def _getItemByIndex(self, index: PyQt5.QtCore.QModelIndex) -> KeyboardShortcutItem: ...
    def _getOrCreateShortcutItem(self, name: str, parent: KeyboardShortcutItem) -> KeyboardShortcutItem: ...
    def columnCount(self, parent: PyQt5.QtCore.QModelIndex) -> int: ...
    def data(self, index: PyQt5.QtCore.QModelIndex, role: int) -> PyQt5.QtCore.QVariant: ...
    def headerData(self, section: int, orientation: PyQt5.QtCore.Qt.Orientation, role: int) -> PyQt5.QtCore.QVariant: ...
    def index(self, row: int, column: int, parent: PyQt5.QtCore.QModelIndex) -> PyQt5.QtCore.QModelIndex: ...
    def parent(self, child: PyQt5.QtCore.QModelIndex) -> PyQt5.QtCore.QModelIndex: ...
    def rowCount(self, parent: PyQt5.QtCore.QModelIndex) -> int: ...
    def setupModelData(self, data: dict): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import PyFnGeolib as FnGeolib
import LoggingAPI as LoggingAPI
import NodegraphAPI as NodegraphAPI
from _typeshed import Incomplete
from types import ModuleType
from typing import ClassVar, Set, Tuple

class IncomingSceneOpDelegate:
    FnAttribute: ClassVar[ModuleType] = ...
    FnGeolib: ClassVar[ModuleType] = ...
    def buildIncomingSceneOp(self, node: NodegraphAPI.Node, interface): ...

class OutgoingAttributesDelegate:
    FnAttribute: ClassVar[ModuleType] = ...
    FnGeolib: ClassVar[ModuleType] = ...
    def buildOutgoingAttributes(self, node: NodegraphAPI.Node, interface): ...

class _IncomingSceneInterface:
    def __init__(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, ops) -> None: ...
    def appendOp(self, opType, opArgs: Incomplete | None = ...): ...
    def getFrameTime(self) -> float: ...
    def getGraphState(self) -> NodegraphAPI.GraphState: ...
    def getOutputPortName(self) -> str: ...

class _OutgoingAttributesInterface:
    def __init__(self, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, attrList) -> None: ...
    def getAttrList(self) -> str: ...
    def getFrameTime(self) -> float: ...
    def getGraphState(self) -> NodegraphAPI.GraphState: ...
    def getOutputAttrList(self): ...
    def getOutputPortName(self) -> str: ...
    def setAttrList(self, attrList): ...

def RegisterIncomingSceneOpDelegate(nodetype, delegate): ...
def RegisterOutgoingAttributesDelegate(nodetype, delegate): ...
def RunIncomingSceneOpDelegate(node: NodegraphAPI.Node, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState): ...
def RunOutgoingAttributesDelegate(node: NodegraphAPI.Node, port: NodegraphAPI.Port, graphState: NodegraphAPI.GraphState, attrList): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtCore
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
from typing import ClassVar, Set, Tuple

class ConditionalVisibilityOpBase(PyQt5.QtCore.QObject):
    conditionalStateEval: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def _ConditionalVisibilityOpBase__targetPolicyChanged(self, event): ...
    def checkState(self): ...
    def freeze(self): ...
    def getProcessedTargetValue(self, value): ...
    def getTargetPolicy(self): ...
    def thaw(self): ...

class _OpAnd(_OpBoolean):
    def checkState(self): ...

class _OpBoolean(PyQt5.QtCore.QObject):
    conditionalStateEval: ClassVar[PyQt5.QtCore.pyqtSignal] = ...
    def __init__(self, policy, hints, prefix) -> None: ...
    def _OpBoolean__operandChanged(self, state): ...
    def checkState(self): ...
    def freeze(self): ...
    def left(self): ...
    def right(self): ...
    def thaw(self): ...

class _OpContains(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpDoesNotContain(_OpContains):
    def checkState(self): ...

class _OpEqualTo(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpGreaterThan(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpGreaterThanOrEqualTo(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpIn(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpLessThan(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpLessThanOrEqualTo(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpNotEqualTo(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpNotIn(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

class _OpOr(_OpBoolean):
    def checkState(self): ...

class _OpRegexMatch(ConditionalVisibilityOpBase):
    def __init__(self, targetPolicy, hints, prefix) -> None: ...
    def checkState(self): ...

def ParseStandardConditionalHints(policy, hints): ...
def RegisterConditionalVisibilityOp(name, obj, pathIsNotParameter: bool = ...): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4FormWidgets.FWidget
import PyQt5.QtCore as QtCore
import PyQt5.QtGui as QtGui
import PyQt5.QtWidgets as QtWidgets
from QT4FormWidgets.FWidget import FBoxLayout as FBoxLayout, FButton as FButton, FDisclosureTriangle as FDisclosureTriangle, FLabel as FLabel, FLockIcon as FLockIcon, FMenu as FMenu, FPixmap as FPixmap, FSpacer as FSpacer, FStateBadge as FStateBadge, FSvgIcon as FSvgIcon, FToggleStateBadge as FToggleStateBadge, FWidget as FWidget
from typing import ClassVar, Set, Tuple

class MultiStateBadge(QT4FormWidgets.FWidget.FStateBadge):
    _MultiStateBadge__stateInfo: ClassVar[list] = ...
    def __init__(self, parent) -> None: ...
    def _MultiStateBadge__menuHide(self): ...
    def _MultiStateBadge__setState(self, state): ...
    def mousePressEvent(self, event): ...
    def setState(self, state): ...

class ToggleStateBadge(QT4FormWidgets.FWidget.FToggleStateBadge):
    _ToggleStateBadge__stateInfo: ClassVar[list] = ...
    def __init__(self, parent) -> None: ...
    def _ToggleStateBadge__setState(self, state): ...
    def mousePressEvent(self, event): ...
    def setState(self, state): ...

def ToggleValuePolicyState(policy): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFCurve as PyFCurve
import PyQt5.QtWidgets
import QT4FormWidgets as QT4FormWidgets
import PyQt5.QtCore as QtCore
import PyQt5.QtWidgets as QtWidgets
import Utils as Utils
from QTFCurve.FCurveSnapSettingsMenu import FCurveSnapSettingsMenu as FCurveSnapSettingsMenu
from typing import ClassVar, Set, Tuple

class FCurveValueEdit(PyQt5.QtWidgets.QWidget):
    class _ValueEditSelectionObserver(PyFCurve.SelectionObserver):
        class _ValueEditFCurveObserver(PyFCurve.FCurveObserver):
            def __init__(self, valueEdit, syncParent) -> None: ...
            def beginValueChange(self, curve): ...
            def curveChanged(self, curve): ...
            def disable(self): ...
            def enable(self): ...
            def endValueChange(self, curve): ...
            def intermediateValueChange(self, curve): ...
        _SYNC_INTERVAL: ClassVar[int] = ...
        def __init__(self, valueEdit) -> None: ...
        def _ValueEditSelectionObserver__directSync(self): ...
        def _ValueEditSelectionObserver__tabClosed(self): ...
        def _getFCurveObserver(self): ...
        def _updateExpressionControl(self, selCurves, selKeys, selSegs): ...
        def _updatePositionControls(self, selKeys): ...
        def _updateResetTangentButton(self, selCurves, selKeys): ...
        def deselected(self, obj): ...
        def getNumSelCurves(self): ...
        def getNumSelKeyframes(self): ...
        def getNumSelSegments(self): ...
        def getNumSelTans(self): ...
        def selected(self, obj): ...
        def sync(self): ...
    def __init__(self, expressionList, graphWidget, parent) -> None: ...
    def _FCurveValueEdit__ExprChanged(self, event): ...
    def _FCurveValueEdit__VisibleUnlocked(self, obj): ...
    def _FCurveValueEdit__XPosChanged(self, event): ...
    def _FCurveValueEdit__YPosChanged(self, event): ...
    def _FCurveValueEdit__tangentReset_CB(self): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyFnAttribute as FnAttribute
import NodegraphAPI as NodegraphAPI
import Utils as Utils
import typing
from Nodes3DAPI.Node3D import Node3D as Node3D
from _typeshed import Incomplete
from typing import Set, Tuple

_Default_Pivot: float
_Default_Rotate: float
_Default_Scale: float
_Default_Translate: float
_Default_UniformScale: float
_ParamHints: dict
_Parameter_XML: str
_xyz: tuple

class TransformNode3D(Node3D):
    def __init__(self) -> None: ...
    def _TransformNode3D__getPivotAttr(self, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def _TransformNode3D__getRotate(self, frameTime, graphState: NodegraphAPI.GraphState): ...
    def _TransformNode3D__getTransformAttr(self, frameTime, graphState: typing.Optional[NodegraphAPI.GraphState] = ...): ...
    def _getOpChain(self, interface): ...
    def addParameterHints(self, attrName, inputDict): ...
    def canOverride(self, attrName): ...
    def setInteractiveTransform(self, path, absScale, absRotate, absTranslate, time): ...
    def setInteractiveTransformFlag(self, path, time): ...
    def setOverride(self, path, attrName, time, attrData, index: Incomplete | None = ..., *args, **kwargs): ...

def _GetArrayParameterConstantValue(parameter, frameTime): ...
def _GetArrayParameterSamples(parameter, graphState: NodegraphAPI.GraphState): ...
def _GetParameterConstantValue(parameter, frameTime): ...
def _GetParameterSampleTimes(parameter, graphState: NodegraphAPI.GraphState): ...
def _GetParameterSamples(parameter, graphState: NodegraphAPI.GraphState): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI as NodegraphAPI
import QT4Widgets as QT4Widgets
from QT4Widgets.FilterablePopupButton import FilterablePopupButton
from _typeshed import Incomplete
from typing import Set, Tuple

class NodeTypePopup(FilterablePopupButton):
    def __init__(self, parent, nodeTypeList: Incomplete | None = ..., flavorList: Incomplete | None = ..., flavorExcludeList: Incomplete | None = ...) -> None: ...
    def _NodeTypePopup__aboutToShow(self): ...
    def _NodeTypePopup__flavorFilter(self, state, name, meta): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from . import TerminalTab as TerminalTab
from UI4.Tabs.EnhancedTerminalTab.TerminalTab import EnhancedTerminalTab as EnhancedTerminalTab
from typing import Set, Tuple

PluginRegistry: list



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

from _typeshed import Incomplete
from typing import Set, Tuple

AnisotropicParamHints: dict
BloomAmountParamHints: dict
BloomEnableParamHints: dict
BloomGroupParamHints: dict
BloomModeParamHints: dict
BloomThresholdParamHints: dict
BorderExtendParamHints: dict
BorderOverscanParamHints: dict
ClampOutputParamHints: dict
DownFilterParamHints: dict
FilterParamHints: dict
GroupFilterParamHints: dict
HighlightCompensationParamHints: dict
MotionBlurEnableParamHints: dict
MotionBlurGroupParamHints: dict
MotionBlurNumSamplesParamHints: dict
MotionBlurOnlyApplyMotionParamHints: dict
MotionBlurShutterParamHints: dict
PremultiplyToggleHints: dict
UpFilterParamHints: dict

def AddCommon2DToNodeHints(d): ...
def AddDictToNodeHints(origHints, additionalHints, prefix): ...
def GetAngleNumberDict(**kwargs): ...
def GetAspectRatioNumberDict(**kwargs): ...
def GetBoundsParamDict(paramName): ...
def GetCameraLensMmNumberDict(**kwargs): ...
def GetCapsuleRgbaDict(exclusive: bool = ..., help: Incomplete | None = ..., label: Incomplete | None = ...): ...
def GetChannelCapsuleColor(channel): ...
def GetCineonOffsetNumberDict(**kwargs): ...
def GetContrastNumberDict(**kwargs): ...
def GetExposureNumberDict(**kwargs): ...
def GetFgBgCombinerStringDict(**kwargs): ...
def GetFilmbackStringDict(**kwargs): ...
def GetGainNumberDict(**kwargs): ...
def GetGammaNumberDict(**kwargs): ...
def GetHueAngleOffsetNumberDict(**kwargs): ...
def GetNormalizedCenterNumberDict(**kwargs): ...
def GetNormalizedNumberDict(**kwargs): ...
def GetOffsetNumberDict(**kwargs): ...
def GetPivotNumberDict(**kwargs): ...
def GetPixelNumberDict(**kwargs): ...
def GetPolygonSidesDict(**kwargs): ...
def GetPositivePixelNumberDict(**kwargs): ...
def GetSaturationNumberDict(**kwargs): ...
def GetSmallPositivePixelNumberDict(**kwargs): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import QT4GLLayerStack as QT4GLLayerStack
import PyQt5.QtCore as QtCore
import Utils as Utils
from QT4GLLayerStack.RectangleLayer import RectangleLayer
from typing import Set, Tuple

class SelectionLayer(RectangleLayer):
    def __init__(self, *args, **kwargs) -> None: ...
    def isOverlay(self): ...
    def paintGL(self): ...
    def processEvent(self, event): ...
    def setEnabled(self, enabled): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import PyQt5.QtWidgets as QtWidgets
from UI4.Widgets.SceneGraphView.ViewLink import ViewLink as ViewLink
from _typeshed import Incomplete
from typing import ClassVar, Set, Tuple

class DebugViewLink(ViewLink):
    _abc_impl: ClassVar[_abc_data] = ...
    __abstractmethods__: ClassVar[frozenset] = ...
    def __init__(self, bridge, parent: Incomplete | None = ...) -> None: ...
    def _DebugViewLink__updateText(self): ...
    def addLocation(self, handle, topLevelHandle): ...
    def addTopLevelLocation(self, topLevelHandle): ...
    def allowMultipleSelection(self): ...
    def collapseLocation(self, handle, topLevelHandle): ...
    def evaluateFilterRules(self, handle: Incomplete | None = ..., topLevelHandle: Incomplete | None = ...): ...
    def expandLocation(self, handle, topLevelHandle): ...
    def getSelectedLocations(self): ...
    def getWidget(self): ...
    def removeLocation(self, handle, topLevelHandle): ...
    def removeTopLevelLocation(self, topLevelHandle): ...
    def resetModel(self): ...
    def scrollToLocation(self, handle, topLevelHandle): ...
    def setAllowMultipleSelection(self, allowMultipleSelection): ...
    def setAttributeDataChildren(self, handle, topLevelHandle, attributeDataChildren): ...
    def setColumnTitles(self, titleInfo): ...
    def setContextMenuEventCallback(self, callback): ...
    def setDragMoveEventCallback(self, callback): ...
    def setDropEventCallback(self, callback): ...
    def setExpandsOnDoubleClick(self, expandsOnDoubleClick): ...
    def setKeyPressEventCallback(self, callback): ...
    def sortChildrenUnderLocation(self, handle, topLevelHandle): ...
    def updateItemDelegates(self): ...
    def updateLocation(self, handle, topLevelHandle): ...
    def updateLocationIcons(self, handle, topLevelHandle): ...
    def updateTopLevelLocation(self, topLevelHandle): ...



# mypy: disable-error-code="misc, override, attr-defined, no-redef, assignment"

import NodegraphAPI
import PyQt5.QtWidgets as QtWidgets
import UI4 as UI4
import Utils as Utils
from typing import Set, Tuple

class ProgressMonitor:
    class InterruptException(RuntimeError): ...
    def __init__(self, updateInterval: float = ...) -> None: ...
    def interrupt(self): ...
    def progress(self, message): ...
    def __del__(self) -> None: ...

def FillCache(node: NodegraphAPI.Node): ...
